@@ -13,8 +13,6 @@
 # the full text of the license.
 
 # pylint: disable=too-many-lines
-# TODO: Address following pylint complaints
-# pylint: disable=invalid-name
 
 import base64
 import datetime
@@ -72,9 +70,8 @@ def attach_file_if_exists(report, path, key=None, overwrite=True, force_unicode=
         attach_file(report, path, key, overwrite, force_unicode)
 
 
+# pylint: disable-next=too-many-return-statements
 def read_file(path, force_unicode=False):
-    # TODO: Split into smaller functions/methods
-    # pylint: disable=too-many-return-statements
     """Return the contents of the specified path.
 
     If the contents is valid UTF-8, or force_unicode is True, then the value
@@ -95,21 +92,21 @@ def read_file(path, force_unicode=False):
             os.close(fd)
             return "Error: path contained symlinks."
         # make sure the file isn't a FIFO or symlink
-        if stat.S_ISREG(st.st_mode):
-            with os.fdopen(fd, "rb") as f:
-                contents = f.read().strip()
-        else:
+        if not stat.S_ISREG(st.st_mode):
             os.close(fd)
             return "Error: path was not a regular file."
-        if force_unicode:
-            return contents.decode("UTF-8", errors="replace")
-        try:
-            return contents.decode("UTF-8")
-        except UnicodeDecodeError:
-            return contents
+        with os.fdopen(fd, "rb") as f:
+            contents = f.read().strip()
     except OSError as error:
         return f"Error: {str(error)}"
 
+    if force_unicode:
+        return contents.decode("UTF-8", errors="replace")
+    try:
+        return contents.decode("UTF-8")
+    except UnicodeDecodeError:
+        return contents
+
 
 def attach_file(report, path, key=None, overwrite=True, force_unicode=False):
     """Attach a file to the report.
@@ -746,6 +743,7 @@ def attach_gsettings_schema(report, schema):
     with subprocess.Popen(
         ["gsettings", "list-recursively", schema], env=env, stdout=subprocess.PIPE
     ) as gsettings:
+        assert gsettings.stdout is not None
         for line in gsettings.stdout:
             try:
                 (schema_name, key, value) = line.split(None, 2)
@@ -757,6 +755,7 @@ def attach_gsettings_schema(report, schema):
     with subprocess.Popen(
         ["gsettings", "list-recursively", schema], stdout=subprocess.PIPE
     ) as gsettings:
+        assert gsettings.stdout is not None
         for line in gsettings.stdout:
             try:
                 (schema_name, key, value) = line.split(None, 2)
@@ -904,6 +903,8 @@ def attach_printing(report):
     )
 
 
+# TODO: Split into smaller functions/methods
+# pylint: disable-next=too-complex
 def attach_mac_events(
     report: ProblemReport, profiles: Iterable[str] | str | None = None
 ) -> None:
