@@ -14,8 +14,6 @@ implementation (like GTK, Qt, or CLI).
 # the full text of the license.
 
 # pylint: disable=too-many-lines
-# TODO: Address following pylint complaints
-# pylint: disable=invalid-name
 
 import argparse
 import ast
@@ -49,11 +47,13 @@ from typing import Any
 import apport.crashdb
 import apport.fileutils
 import apport.logging
+import apport.report
 import apport.REThread
+from apport.hook_ui import HookUI, NoninteractiveHookUI
 from apport.packaging_impl import impl as packaging
 from apport.user_group import get_process_user_and_group
 
-__version__ = "2.32.0"
+__version__ = "2.33.1"
 
 
 symptom_script_dir = os.environ.get("APPORT_SYMPTOMS_DIR", "/usr/share/apport/symptoms")
@@ -180,7 +180,7 @@ def thread_collect_info(
     report, reportfile, package, ui, symptom_script=None, ignore_uninstalled=False
 ):
     # TODO: Split into smaller functions/methods
-    # pylint: disable=too-many-branches,too-many-statements
+    # pylint: disable=too-complex,too-many-branches,too-many-statements
     """Collect information about report.
 
     Encapsulate calls to add_*_info() and update given report, so that this
@@ -417,7 +417,7 @@ class UserInterface:
 
     def run_crash(self, report_file: str) -> None:
         # TODO: Split into smaller functions/methods
-        # pylint: disable=too-many-branches,too-many-return-statements
+        # pylint: disable=too-complex,too-many-branches,too-many-return-statements
         # pylint: disable=too-many-statements
         """Present and report a particular crash.
 
@@ -559,14 +559,7 @@ class UserInterface:
         noninteractive processes will collect the remaining information and
         mark the report for uploading.
         """
-        self.report = apport.Report("Hang")
-
-        if not self.args.pid:
-            self.ui_error_message(
-                _("No PID specified"),
-                _("You need to specify a PID. See --help for more information."),
-            )
-            return False
+        self.report = apport.report.Report("Hang")
 
         try:
             self.report.add_proc_info(pid)
@@ -587,12 +580,12 @@ class UserInterface:
         self.cur_package = apport.fileutils.find_file_package(path)
         self.report.add_os_info()
         allowed_to_report = apport.fileutils.allowed_to_report()
-        response = self.ui_present_report_details(allowed_to_report, modal_for=int(pid))
+        response = self.ui_present_report_details(allowed_to_report, modal_for=pid)
         if response.report:
             apport.fileutils.mark_hanging_process(self.report, pid)
-            os.kill(int(pid), signal.SIGABRT)
+            os.kill(pid, signal.SIGABRT)
         else:
-            os.kill(int(pid), signal.SIGKILL)
+            os.kill(pid, signal.SIGKILL)
 
         if response.restart:
             self.wait_for_pid(pid)
@@ -620,7 +613,7 @@ class UserInterface:
 
     def run_report_bug(self, symptom_script: str | None = None) -> bool:
         # TODO: Split into smaller functions/methods
-        # pylint: disable=too-many-branches,too-many-return-statements
+        # pylint: disable=too-complex,too-many-branches,too-many-return-statements
         # pylint: disable=too-many-statements
         """Report a bug.
 
@@ -644,7 +637,7 @@ class UserInterface:
             )
             return False
 
-        self.report = apport.Report("Bug")
+        self.report = apport.report.Report("Bug")
 
         # if PID is given, add info
         if self.args.pid:
@@ -745,6 +738,8 @@ class UserInterface:
 
         return True
 
+    # TODO: Split into smaller functions/methods
+    # pylint: disable-next=too-complex
     def run_update_report(self) -> bool:
         """Update an existing bug with locally collected information."""
         # avoid irrelevant noise
@@ -776,7 +771,7 @@ class UserInterface:
                 return False
 
         # list of affected source packages
-        self.report = apport.Report("Bug")
+        self.report = apport.report.Report("Bug")
         if self.args.package:
             pkgs = [self.args.package.strip()]
         else:
@@ -905,7 +900,7 @@ class UserInterface:
 
     def run_argv(self) -> bool:
         # TODO: Split into smaller functions/methods
-        # pylint: disable=too-many-return-statements
+        # pylint: disable=too-complex,too-many-return-statements
         """Call appropriate run_* method according to command line arguments.
 
         Return True if at least one report has been processed, and False
@@ -915,8 +910,13 @@ class UserInterface:
             self.run_symptom()
             return True
         if self.args.hanging:
-            self.run_hang(self.args.pid)
-            return True
+            if not self.args.pid:
+                self.ui_error_message(
+                    _("No PID specified"),
+                    _("You need to specify a PID. See --help for more information."),
+                )
+                return False
+            return self.run_hang(int(self.args.pid))
         if self.args.filebug:
             return self.run_report_bug()
         if self.args.update_report is not None:
@@ -1010,7 +1010,7 @@ class UserInterface:
 
     def parse_argv(self, argv: list[str]) -> argparse.Namespace:
         # TODO: Split into smaller functions/methods
-        # pylint: disable=too-many-branches,too-many-statements
+        # pylint: disable=too-complex,too-many-branches,too-many-statements
         """Parse command line options.
 
         If a single argument is given without any options, this tries to "do
@@ -1405,7 +1405,8 @@ class UserInterface:
         on_finished: Callable[[], None] | None = None,
     ) -> None:
         # TODO: Split into smaller functions/methods
-        # pylint: disable=too-many-branches,too-many-locals,too-many-statements
+        # pylint: disable=too-complex,too-many-branches,too-many-locals
+        # pylint: disable=too-many-statements
         """Collect additional information.
 
         Call all the add_*_info() methods and display a progress dialog during
@@ -1459,8 +1460,8 @@ class UserInterface:
                     return
 
         # check if binary changed since the crash happened
-        if "ExecutablePath" in self.report and "ExecutableTimestamp" in self.report:
-            orig_time = int(self.report["ExecutableTimestamp"])
+        orig_time = self.report.get_executable_timestamp()
+        if orig_time is not None:
             del self.report["ExecutableTimestamp"]
             cur_time = int(os.stat(self.report["ExecutablePath"]).st_mtime)
 
@@ -1727,6 +1728,8 @@ class UserInterface:
         message = _("Unable to start web browser to open %s.") % url
         self.ui_error_message(title, message + error_details)
 
+    # TODO: Split into smaller functions/methods
+    # pylint: disable-next=too-complex
     def file_report(self) -> None:
         """Upload the current report and guide the user to the reporting
         web page."""
@@ -1816,7 +1819,7 @@ class UserInterface:
         returned.
         """
         try:
-            self.report = apport.Report()
+            self.report = apport.report.Report()
             with open(path, "rb") as f:
                 self.report.load(f, binary="compressed")
             if "ProblemType" not in self.report:
@@ -2068,126 +2071,3 @@ class UserInterface:
         Return path if the user selected a file, or None if cancelled.
         """
         raise NotImplementedError("this function must be overridden by subclasses")
-
-
-class HookUI:
-    """Interactive functions which can be used in package hooks.
-
-    This provides an interface for package hooks which need to ask interactive
-    questions. Directly passing the UserInterface instance to the hooks needs
-    to be avoided, since we need to call the UI methods in a different thread,
-    and also don't want hooks to be able to poke in the UI.
-    """
-
-    def __init__(self, ui):
-        """Create a HookUI object.
-
-        ui is the UserInterface instance to wrap.
-        """
-        self.ui = ui
-
-        # variables for communicating with the UI thread
-        self._request_event = threading.Event()
-        self._response_event = threading.Event()
-        self._request_fn = None
-        self._request_args = None
-        self._response = None
-
-    #
-    # API for hooks
-    #
-
-    def information(self, text):
-        """Show an information with OK/Cancel buttons.
-
-        This can be used for asking the user to perform a particular action,
-        such as plugging in a device which does not work.
-        """
-        return self._trigger_ui_request("ui_info_message", "", text)
-
-    def yesno(self, text):
-        """Show a yes/no question.
-
-        Return True if the user selected "Yes", False if selected "No" or
-        "None" on cancel/dialog closing.
-        """
-        return self._trigger_ui_request("ui_question_yesno", text)
-
-    def choice(self, text, options, multiple=False):
-        """Show an question with predefined choices.
-
-        options is a list of strings to present. If multiple is True, they
-        should be check boxes, if multiple is False they should be radio
-        buttons.
-
-        Return list of selected option indexes, or None if the user cancelled.
-        If multiple == False, the list will always have one element.
-        """
-        return self._trigger_ui_request("ui_question_choice", text, options, multiple)
-
-    def file(self, text):
-        """Show a file selector dialog.
-
-        Return path if the user selected a file, or None if cancelled.
-        """
-        return self._trigger_ui_request("ui_question_file", text)
-
-    #
-    # internal API for inter-thread communication
-    #
-
-    def _trigger_ui_request(self, fn, *args):
-        """Called by HookUi functions in info collection thread."""
-        # only one at a time
-        assert not self._request_event.is_set()
-        assert not self._response_event.is_set()
-        assert self._request_fn is None
-
-        self._response = None
-        self._request_fn = fn
-        self._request_args = args
-        self._request_event.set()
-        self._response_event.wait()
-
-        self._request_fn = None
-        self._response_event.clear()
-
-        return self._response
-
-    def process_event(self):
-        """Called by GUI thread to check and process hook UI requests."""
-        # sleep for 0.1 seconds to wait for events
-        self._request_event.wait(0.1)
-        if not self._request_event.is_set():
-            return
-
-        assert not self._response_event.is_set()
-        self._request_event.clear()
-        self._response = getattr(self.ui, self._request_fn)(*self._request_args)
-        self._response_event.set()
-
-
-class NoninteractiveHookUI(HookUI):
-    """HookUI variant that does not ask the user any questions."""
-
-    def __init__(self):
-        super().__init__(None)
-
-    def __repr__(self) -> str:
-        return f"{self.__class__.__name__}()"
-
-    def information(self, text):
-        return None
-
-    def yesno(self, text):
-        return None
-
-    def choice(self, text, options, multiple=False):
-        return None
-
-    def file(self, text):
-        return None
-
-    def process_event(self):
-        # Give other threads some chance to run
-        time.sleep(0.1)
