@@ -11,8 +11,6 @@
 # the full text of the license.
 
 # pylint: disable=too-many-lines
-# TODO: Address following pylint complaints
-# pylint: disable=invalid-name
 
 import atexit
 import email
@@ -24,12 +22,15 @@ import tempfile
 import unittest
 import unittest.mock
 from collections.abc import Callable
-from typing import Any
+from typing import TYPE_CHECKING, Any
 from unittest.mock import MagicMock
 
 try:
     from launchpadlib.errors import HTTPError
 
+    if TYPE_CHECKING:
+        from lazr.restfulclient.resource import Entry
+
     IMPORT_ERROR = None
 except ImportError as error:
     IMPORT_ERROR = error
@@ -726,7 +727,7 @@ and more
         )
 
     @staticmethod
-    def _get_bug_target(db: CrashDatabase, report: Report) -> object | None:
+    def _get_bug_target(db: CrashDatabase, report: Report) -> "Entry | None":
         """Return the bug_target for this report."""
         project = db.options.get("project")
         if "SourcePackage" in report:
@@ -831,7 +832,7 @@ and more
         bug = self.crashdb.launchpad.bugs[crash_id]
         self.assertIn("regression-retracer", bug.tags)
 
-    def test_project(self):
+    def test_project(self) -> None:
         """Test reporting crashes against a project instead of a distro."""
         launchpad_instance = os.environ.get("APPORT_LAUNCHPAD_INSTANCE") or "qastaging"
         # crash database for langpack-o-matic project (this does not have
@@ -861,6 +862,7 @@ NameError: global name 'weird' is not defined"""
 
         # file it
         bug_target = self._get_bug_target(crashdb, r)
+        assert bug_target is not None
         self.assertEqual(bug_target.name, "langpack-o-matic")
 
         crash_id, web_link = self._file_bug(bug_target, r)
@@ -896,7 +898,7 @@ NameError: global name 'weird' is not defined"""
         self.assertEqual(r["Architecture"], "amd64")
         self.assertTrue(r["DistroRelease"].startswith("Ubuntu "))
 
-    def test_escalation(self):
+    def test_escalation(self) -> None:
         """Escalating bugs with more than 10 duplicates"""
         launchpad_instance = os.environ.get("APPORT_LAUNCHPAD_INSTANCE") or "qastaging"
         db = CrashDatabase(
@@ -996,7 +998,7 @@ NameError: global name 'weird' is not defined"""
             with open("crash.c", "w", encoding="utf-8") as fd:
                 fd.write(
                     """
-int f(x) {
+int f(int x) {
     int* p = 0; *p = x;
     return x+1;
 }
