@@ -1,8 +1,5 @@
 """Integration tests for the apport.fileutils module."""
 
-# TODO: Address following pylint complaints
-# pylint: disable=invalid-name
-
 import glob
 import os
 import pwd
@@ -34,15 +31,14 @@ class T(unittest.TestCase):
         apport.fileutils.core_dir = tempfile.mkdtemp()
         self.orig_report_dir = apport.fileutils.report_dir
         apport.fileutils.report_dir = tempfile.mkdtemp()
-        self.orig_config_file = apport.fileutils._config_file
+        self.orig_config_file = apport.fileutils._CONFIG_FILE
 
-    def tearDown(self):
+    def tearDown(self) -> None:
         shutil.rmtree(apport.fileutils.core_dir)
         apport.fileutils.core_dir = self.orig_core_dir
         shutil.rmtree(apport.fileutils.report_dir)
         apport.fileutils.report_dir = self.orig_report_dir
-        self.orig_report_dir = None
-        apport.fileutils._config_file = self.orig_config_file
+        apport.fileutils._CONFIG_FILE = self.orig_config_file
 
     @staticmethod
     def _create_reports(create_inaccessible: bool = False) -> list[str]:
@@ -74,10 +70,10 @@ class T(unittest.TestCase):
 
             display_num = 0
             no_display_num = 0
-            for desktop_file in apport.packaging.get_files(pkg):
-                if not desktop_path_re.match(desktop_file):
+            for desktop_filename in apport.packaging.get_files(pkg):
+                if not desktop_path_re.match(desktop_filename):
                     continue
-                with open(desktop_file, "rb") as desktop_file:
+                with open(desktop_filename, "rb") as desktop_file:
                     if b"NoDisplay=true" in desktop_file.read():
                         no_display_num += 1
                     else:
@@ -114,6 +110,7 @@ class T(unittest.TestCase):
 
         d = apport.fileutils.find_package_desktopfile(onedesktop)
         self.assertIsNotNone(d, f"one-desktop package {onedesktop}")
+        assert d is not None
         self.assertTrue(os.path.exists(d))
         self.assertTrue(d.endswith(".desktop"))
 
@@ -149,7 +146,6 @@ class T(unittest.TestCase):
     def test_find_file_package(self) -> None:
         """find_file_package()"""
         self.assertEqual(apport.fileutils.find_file_package("/bin/bash"), "bash")
-        self.assertEqual(apport.fileutils.find_file_package("/bin/cat"), "coreutils")
         self.assertIsNone(apport.fileutils.find_file_package("/nonexisting"))
 
     def test_seen(self) -> None:
@@ -356,21 +352,21 @@ f6423dfbc4faf022e58b4d3f5ff71a70  {f2}
     def test_get_config(self) -> None:
         """get_config()"""
         # nonexisting
-        apport.fileutils._config_file = "/nonexisting"
+        apport.fileutils._CONFIG_FILE = "/nonexisting"
         self.assertIsNone(apport.fileutils.get_config("main", "foo"))
         self.assertEqual(apport.fileutils.get_config("main", "foo", "moo"), "moo")
         apport.fileutils._get_config_parser.cache_clear()
 
         # empty
         with tempfile.NamedTemporaryFile() as f:
-            apport.fileutils._config_file = f.name
+            apport.fileutils._CONFIG_FILE = f.name
             self.assertIsNone(apport.fileutils.get_config("main", "foo"))
             self.assertEqual(apport.fileutils.get_config("main", "foo", "moo"), "moo")
             apport.fileutils._get_config_parser.cache_clear()
 
             # nonempty
             f.write(
-                b"[main]\none=1\ntwo = TWO\nb1 = 1\nb2=False\n" b"[spethial]\none= 99\n"
+                b"[main]\none=1\ntwo = TWO\nb1 = 1\nb2=False\n[spethial]\none= 99\n"
             )
             f.flush()
             self.assertIsNone(apport.fileutils.get_config("main", "foo"))
@@ -448,51 +444,11 @@ f6423dfbc4faf022e58b4d3f5ff71a70  {f2}
             apport.fileutils.links_with_shared_library("/etc/passwd", "libc")
         )
 
-    def test_get_core_path(self) -> None:
-        """get_core_path()"""
-        boot_id = apport.fileutils.get_boot_id()
-
-        # Basic test
-        (core_name, core_path) = apport.fileutils.get_core_path(
-            pid=123, exe="/usr/bin/test", uid=234, timestamp=222222
-        )
-        expected = f"core._usr_bin_test.234.{boot_id}.123.222222"
-        expected_path = os.path.join(apport.fileutils.core_dir, expected)
-        self.assertEqual(core_name, expected)
-        self.assertEqual(core_path, expected_path)
-
-        # Test dots in exe names
-        (core_name, core_path) = apport.fileutils.get_core_path(
-            pid=123, exe="/usr/bin/test.sh", uid=234, timestamp=222222
-        )
-        expected = f"core._usr_bin_test_sh.234.{boot_id}.123.222222"
-        expected_path = os.path.join(apport.fileutils.core_dir, expected)
-        self.assertEqual(core_name, expected)
-        self.assertEqual(core_path, expected_path)
-
-        # Test no exe name
-        (core_name, core_path) = apport.fileutils.get_core_path(
-            pid=123, exe=None, uid=234, timestamp=222222
-        )
-        expected = f"core.unknown.234.{boot_id}.123.222222"
-        expected_path = os.path.join(apport.fileutils.core_dir, expected)
-        self.assertEqual(core_name, expected)
-        self.assertEqual(core_path, expected_path)
-
-        # Test no uid
-        (core_name, core_path) = apport.fileutils.get_core_path(
-            pid=123, exe="/usr/bin/test", uid=None, timestamp=222222
-        )
-        expected = f"core._usr_bin_test.{str(os.getuid())}.{boot_id}.123.222222"
-        expected_path = os.path.join(apport.fileutils.core_dir, expected)
-        self.assertEqual(core_name, expected)
-        self.assertEqual(core_path, expected_path)
-
     def test_clean_core_directory(self) -> None:
         """clean_core_directory()"""
         fake_uid = 5150
         extra_core_files = 4
-        num_core_files = apport.fileutils.max_corefiles_per_uid + extra_core_files
+        num_core_files = apport.fileutils.MAX_COREFILES_PER_UID + extra_core_files
 
         # Create some test files
         for x in range(num_core_files):
@@ -520,15 +476,15 @@ f6423dfbc4faf022e58b4d3f5ff71a70  {f2}
         apport.fileutils.clean_core_directory(fake_uid)
 
         # Make sure we have the proper number of test files. We should
-        # have one less than max_corefiles_per_uid.
+        # have one less than MAX_COREFILES_PER_UID.
         self.assertEqual(
-            apport.fileutils.max_corefiles_per_uid - 1,
+            apport.fileutils.MAX_COREFILES_PER_UID - 1,
             len(apport.fileutils.find_core_files_by_uid(fake_uid)),
         )
         self.assertEqual(1, len(apport.fileutils.find_core_files_by_uid(fake_uid + 1)))
 
         # Make sure we deleted the oldest ones
-        for x in range(apport.fileutils.max_corefiles_per_uid - 1):
+        for x in range(apport.fileutils.MAX_COREFILES_PER_UID - 1):
             offset = extra_core_files + x + 1
             core_path = apport.fileutils.get_core_path(
                 pid=123 + offset,
