@@ -10,9 +10,6 @@
 
 """Test apport_python_hook.py."""
 
-# TODO: Address following pylint complaints
-# pylint: disable=invalid-name
-
 import atexit
 import os
 import re
@@ -183,18 +180,18 @@ func(42)
         reports = apport.fileutils.get_new_reports()
         self.assertEqual(len(reports), 1)
 
-    def test_symlink(self):
+    def test_symlink(self) -> None:
         """Python crash of a symlinked program resolves to target."""
         script = self._test_crash()
 
         # load report for this
         reports = apport.fileutils.get_new_reports()
         self.assertEqual(len(reports), 1, "crashed Python program produced a report")
-        pr1 = apport.Report()
+        pr1 = apport.report.Report()
         with open(reports[0], "rb") as f:
             pr1.load(f)
-        for f in apport.fileutils.get_all_reports():
-            os.unlink(f)
+        for report in apport.fileutils.get_all_reports():
+            os.unlink(report)
 
         script_link = os.path.join(os.path.dirname(script), "script-link")
         os.symlink(os.path.basename(script), script_link)
@@ -214,7 +211,7 @@ func(42)
         # get report for symlinked crash
         reports = apport.fileutils.get_new_reports()
         self.assertEqual(len(reports), 1, "crashed Python program produced a report")
-        pr2 = apport.Report()
+        pr2 = apport.report.Report()
         with open(reports[0], "rb") as f:
             pr2.load(f)
 
@@ -372,7 +369,7 @@ func(42)
         finally:
             os.chdir(orig_cwd)
 
-    def test_ignoring(self):
+    def test_ignoring(self) -> None:
         """The Python crash hook respects the ignore list."""
         # put the script into /var/tmp, since that isn't ignored in the
         # hook
@@ -408,7 +405,7 @@ func(42)
                 r = apport.report.Report()
                 r["ExecutablePath"] = script
                 r.mark_ignore()
-                r = None
+                del r
 
                 process = subprocess.run(
                     [script, "testarg1", "testarg2"],
@@ -487,7 +484,7 @@ func(42)
         exe = pr["ExecutablePath"]
         self.assertEqual(pr.crash_signature(), f"{exe}:OSError:{exe}@11:g")
 
-    def test_getcwd_error(self):
+    def test_getcwd_error(self) -> None:
         """Raise FileNotFoundError on os.getcwd() call."""
         for relpath in (True, False):
             with self.subTest(relpath=relpath):
@@ -506,7 +503,9 @@ func(42)
                     relpath=relpath,
                 )
                 pr = self._load_report()
-                self.assertIn(":FileNotFoundError:", pr.crash_signature())
+                crash_signature = pr.crash_signature()
+                assert crash_signature is not None
+                self.assertIn(":FileNotFoundError:", crash_signature)
                 self.assertIn("os.getcwd()\n", pr["Traceback"])
                 self.assertIn("\nFileNotFoundError", pr["Traceback"])
 
@@ -528,11 +527,11 @@ func(42)
         exe = pr["ExecutablePath"]
         self.assertEqual(pr.crash_signature(), f"{exe}:FileNotFoundError:{exe}@11:g")
 
-    def _load_report(self) -> apport.Report:
+    def _load_report(self) -> apport.report.Report:
         """Ensure that there is exactly one crash report and load it."""
         reports = apport.fileutils.get_new_reports()
         self.assertEqual(len(reports), 1, "crashed Python program produced a report")
-        pr = apport.Report()
+        pr = apport.report.Report()
         with open(reports[0], "rb") as f:
             pr.load(f)
         return pr
