@@ -1,8 +1,6 @@
 """Integration tests for the apport.report module."""
 
 # pylint: disable=too-many-lines
-# TODO: Address following pylint complaints
-# pylint: disable=invalid-name
 
 import atexit
 import grp
@@ -24,7 +22,7 @@ from unittest.mock import MagicMock
 import apport.packaging
 import apport.report
 import problem_report
-from tests.helper import skip_if_command_is_missing
+from tests.helper import get_gnu_coreutils_cmd, skip_if_command_is_missing
 from tests.paths import patch_data_dir, restore_data_dir
 
 
@@ -188,8 +186,9 @@ class T(unittest.TestCase):
         self.assertNotIn("InterpreterPath", pr)
 
         # check escaping of ProcCmdline
+        catcmd = get_gnu_coreutils_cmd("cat")
         with subprocess.Popen(
-            ["cat", "/foo bar", "\\h", "\\ \\", "-"],
+            [catcmd, "/foo bar", "\\h", "\\ \\", "-"],
             stdin=subprocess.PIPE,
             stdout=subprocess.PIPE,
             stderr=subprocess.PIPE,
@@ -199,10 +198,10 @@ class T(unittest.TestCase):
             pr.add_proc_info(pid=cat.pid)
             self.assertEqual(pr.pid, cat.pid)
             cat.communicate(b"\n")
-        self.assertEqual(pr["ProcCmdline"], "cat /foo\\ bar \\\\h \\\\\\ \\\\ -")
-        self.assertEqual(pr["ExecutablePath"], "/usr/bin/cat")
+        self.assertEqual(pr["ProcCmdline"], f"{catcmd} /foo\\ bar \\\\h \\\\\\ \\\\ -")
+        self.assertEqual(pr["ExecutablePath"], catcmd)
         self.assertNotIn("InterpreterPath", pr)
-        self.assertIn("/bin/cat", pr["ProcMaps"])
+        self.assertIn(pr["ExecutablePath"], pr["ProcMaps"])
         self.assertIn("[stack]", pr["ProcMaps"])
 
         # check correct handling of executable symlinks
@@ -984,7 +983,7 @@ int main() { return f(42); }
         self._validate_gdb_fields(pr)
         self.assertNotIn("AssertionMessage", pr)
 
-    def test_add_gdb_info_abort_glib(self):
+    def test_add_gdb_info_abort_glib(self) -> None:
         """add_gdb_info() with glib assertion"""
         code = textwrap.dedent(
             """\
@@ -1012,46 +1011,6 @@ int main() { return f(42); }
             pr["AssertionMessage"],
         )
 
-    # disabled: __nih_abort_msg symbol not available (LP: #1580601)
-    def disabled_test_add_gdb_info_abort_libnih(self):
-        """add_gdb_info() with libnih assertion"""
-        (fd, script) = tempfile.mkstemp()
-        assert not os.path.exists("core")
-        try:
-            os.close(fd)
-
-            # create a test script which produces a core dump for us
-            with open(script, "w", encoding="utf-8") as fd:
-                fd.write(
-                    textwrap.dedent(
-                        """\
-                        #!/bin/sh
-                        gcc -o $0.bin -x c - \
-                            `pkg-config --cflags --libs libnih` <<EOF
-                        #include <libnih.h>
-                        int main() { nih_assert (1 < 0); }
-                        EOF
-                        ulimit -c unlimited
-                        $0.bin 2>/dev/null
-                        """
-                    )
-                )
-            # call script and verify that it gives us a proper ELF core dump
-            assert subprocess.call(["/bin/sh", script]) != 0
-            self._validate_core("core")
-
-            pr = apport.report.Report()
-            pr["ExecutablePath"] = script + ".bin"
-            pr["CoreDump"] = ("core",)
-            pr.add_gdb_info()
-        finally:
-            os.unlink(script)
-            os.unlink(script + ".bin")
-            os.unlink("core")
-
-        self._validate_gdb_fields(pr)
-        self.assertIn("Assertion failed in main: 1 < 0", pr["AssertionMessage"])
-
     def test_search_bug_patterns(self) -> None:
         # TODO: Split into separate test cases
         # pylint: disable=too-many-statements
@@ -1489,11 +1448,11 @@ int main() { return f(42); }
         apport.report.GENERAL_HOOK_DIR = tempfile.mkdtemp()
         orig_package_hook_dir = apport.report.PACKAGE_HOOK_DIR
         apport.report.PACKAGE_HOOK_DIR = tempfile.mkdtemp()
-        orig_opt_dir = apport.report._opt_dir
-        apport.report._opt_dir = tempfile.mkdtemp()
+        orig_opt_dir = apport.report._OPT_DIR
+        apport.report._OPT_DIR = tempfile.mkdtemp()
         try:
             opt_hook_dir = os.path.join(
-                apport.report._opt_dir,
+                apport.report._OPT_DIR,
                 "foolabs.example.com",
                 "foo",
                 "share",
@@ -1528,7 +1487,7 @@ int main() { return f(42); }
             r["Package"] = "foo-bin 0.2"
             r["SourcePackage"] = "foo"
             r["ExecutablePath"] = (
-                f"{apport.report._opt_dir}/foolabs.example.com/foo/bin/frob"
+                f"{apport.report._OPT_DIR}/foolabs.example.com/foo/bin/frob"
             )
 
             self.assertEqual(r.add_hooks_info(), False)
@@ -1536,10 +1495,10 @@ int main() { return f(42); }
         finally:
             shutil.rmtree(apport.report.GENERAL_HOOK_DIR)
             shutil.rmtree(apport.report.PACKAGE_HOOK_DIR)
-            shutil.rmtree(apport.report._opt_dir)
+            shutil.rmtree(apport.report._OPT_DIR)
             apport.report.GENERAL_HOOK_DIR = orig_general_hook_dir
             apport.report.PACKAGE_HOOK_DIR = orig_package_hook_dir
-            apport.report._opt_dir = orig_opt_dir
+            apport.report._OPT_DIR = orig_opt_dir
 
     @unittest.mock.patch("sys.stderr", new_callable=io.StringIO)
     def test_add_hooks_info_errors(self, stderr_mock: MagicMock) -> None:
@@ -1612,10 +1571,12 @@ int main() { return f(42); }
 
     def test_ignoring(self) -> None:
         """mark_ignore() and check_ignored()."""
-        orig_ignore_file = apport.report.apport.report._ignore_file
-        workdir = tempfile.mkdtemp()
-        apport.report.apport.report._ignore_file = os.path.join(workdir, "ignore.xml")
-        try:
+        with (
+            tempfile.TemporaryDirectory() as workdir,
+            unittest.mock.patch(
+                "apport.report._ignore_file", os.path.join(workdir, "ignore.xml")
+            ),
+        ):
             with open(os.path.join(workdir, "bash"), "w", encoding="utf-8") as fd:
                 fd.write("bash")
             with open(os.path.join(workdir, "crap"), "w", encoding="utf-8") as fd:
@@ -1655,9 +1616,7 @@ int main() { return f(42); }
             self.assertEqual(cp_rep.check_ignored(), False)
 
             # do not complain about an empty ignore file
-            with open(
-                apport.report.apport.report._ignore_file, "w", encoding="utf-8"
-            ) as fd:
+            with open(apport.report._ignore_file, "w", encoding="utf-8") as fd:
                 fd.write("")
             self.assertEqual(bash_rep.check_ignored(), False)
             self.assertEqual(crap_rep.check_ignored(), False)
@@ -1666,20 +1625,15 @@ int main() { return f(42); }
             # does not crash if the executable went away under our feet
             crap_rep["ExecutablePath"] = "/non existing"
             crap_rep.mark_ignore()
-            self.assertEqual(
-                os.path.getsize(apport.report.apport.report._ignore_file), 0
-            )
-        finally:
-            shutil.rmtree(workdir)
-            apport.report.apport.report._ignore_file = orig_ignore_file
+            self.assertEqual(os.path.getsize(apport.report._ignore_file), 0)
 
     def test_denylisting(self) -> None:
         """check_ignored() for system-wise denylist."""
-        orig_denylist_dir = apport.report._DENYLIST_DIR
-        apport.report._DENYLIST_DIR = tempfile.mkdtemp()
-        orig_ignore_file = apport.report._ignore_file
-        apport.report._ignore_file = "/nonexistent"
-        try:
+        with (
+            tempfile.TemporaryDirectory() as denylist_dir,
+            unittest.mock.patch("apport.report._DENYLIST_DIR", denylist_dir),
+            unittest.mock.patch("apport.report._ignore_file", "/nonexistent"),
+        ):
             bash_rep = apport.report.Report()
             bash_rep["ExecutablePath"] = "/bin/bash"
             crap_rep = apport.report.Report()
@@ -1720,18 +1674,14 @@ int main() { return f(42); }
                 fd.write("/bin/bash\n")
             self.assertEqual(bash_rep.check_ignored(), True)
             self.assertEqual(crap_rep.check_ignored(), True)
-        finally:
-            shutil.rmtree(apport.report._DENYLIST_DIR)
-            apport.report._DENYLIST_DIR = orig_denylist_dir
-            apport.report._ignore_file = orig_ignore_file
 
     def test_allowlisting(self) -> None:
         """check_ignored() for system-wise allowlist."""
-        orig_allowlist_dir = apport.report._ALLOWLIST_DIR
-        apport.report._ALLOWLIST_DIR = tempfile.mkdtemp()
-        orig_ignore_file = apport.report.apport.report._ignore_file
-        apport.report.apport.report._ignore_file = "/nonexistent"
-        try:
+        with (
+            tempfile.TemporaryDirectory() as allowlist_dir,
+            unittest.mock.patch("apport.report._ALLOWLIST_DIR", allowlist_dir),
+            unittest.mock.patch("apport.report._ignore_file", "/nonexistent"),
+        ):
             bash_rep = apport.report.Report()
             bash_rep["ExecutablePath"] = "/bin/bash"
             crap_rep = apport.report.Report()
@@ -1774,10 +1724,6 @@ int main() { return f(42); }
                 fd.write("/bin/bas\n/bin/bashh\nbash\n")
             self.assertEqual(bash_rep.check_ignored(), True)
             self.assertEqual(crap_rep.check_ignored(), False)
-        finally:
-            shutil.rmtree(apport.report._ALLOWLIST_DIR)
-            apport.report._ALLOWLIST_DIR = orig_allowlist_dir
-            apport.report.apport.report._ignore_file = orig_ignore_file
 
     def test_obsolete_packages(self) -> None:
         """obsolete_packages()."""
@@ -1816,6 +1762,7 @@ int main() { return f(42); }
         pr.add_proc_info()
         self.assertIsNone(pr._address_to_offset(0))
         res = pr._address_to_offset(int(pr["ProcMaps"].split("-", 1)[0], 16) + 5)
+        assert res is not None
         self.assertEqual(res.split("+", 1)[1], "5")
         self.assertIn("python", res.split("+", 1)[0])
 
