@@ -10,14 +10,13 @@
 """Integration tests for data/apport."""
 
 # pylint: disable=too-many-lines
-# TODO: Address following pylint complaints
-# pylint: disable=invalid-name
 
 import argparse
 import collections
 import contextlib
 import datetime
 import grp
+import io
 import os
 import pathlib
 import resource
@@ -32,6 +31,7 @@ import textwrap
 import time
 import typing
 import unittest
+import unittest.mock
 from collections.abc import Callable, Iterable, Iterator
 from pathlib import Path
 from unittest.mock import MagicMock
@@ -40,8 +40,11 @@ import psutil
 import pytest
 
 import apport.fileutils
+import apport.report
 from tests.helper import (
+    get_gnu_coreutils_cmd,
     import_module_from_file,
+    pidfd_open,
     read_shebang,
     run_test_executable,
     wait_for_sleeping_state,
@@ -59,43 +62,45 @@ except ImportError as import_error:
 APPORT_PATH = get_data_directory() / "apport"
 apport_binary = import_module_from_file(APPORT_PATH)
 
+# SUID binary that immediately drops privilege then sleeps
+DROPSUID_SOURCE = """\
+#include <unistd.h>
+#include <stdio.h>
+#include <errno.h>
+
+int main() {
+    int euid = geteuid();
+    int uid = getuid();
+
+    // We need to be suid
+    if (uid == euid) {
+        fprintf(stderr, "uid: %d, euid: %d\\n", uid, euid);
+        return 1;
+    }
+    // This call is supposed to succeed?!
+    if (seteuid(uid)) {
+        fprintf(stderr, "errno: %d\\n", errno);
+        return 2;
+    }
+    // We actually check that it succeeded.
+    if (geteuid() != uid)
+        return 3;
+    sleep(60);
+    return 0;
+}
+"""
+
 
 @contextlib.contextmanager
-def create_dropsuid() -> Iterator[str]:
-    """Compiles a suid binary that immediately drops privilege then sleeps."""
-    DROPSUID_SOURCE = """
-        #include <unistd.h>
-        #include <stdio.h>
-        #include <errno.h>
-
-        int main() {
-            int euid = geteuid();
-            int uid = getuid();
-
-            // We need to be suid
-            if (uid == euid) {
-                fprintf(stderr, "uid: %d, euid: %d\\n", uid, euid);
-                return 1;
-            }
-            // This call is supposed to succeed?!
-            if (seteuid(uid)) {
-                fprintf(stderr, "errno: %d\\n", errno);
-                return 2;
-            }
-            // We actually check that it succeeded.
-            if (geteuid() != uid)
-                return 3;
-            sleep(60);
-            return 0;
-        }
-    """
+def compile_c_code(name: str, c_code: str, tmpdir: str = "/var/tmp") -> Iterator[str]:
+    """Compiles the given C code."""
     if not os.path.exists("/usr/bin/gcc"):
         pytest.skip("This test needs GCC available")
-    with tempfile.TemporaryDirectory(dir="/var/tmp") as d:
+    with tempfile.TemporaryDirectory(dir=tmpdir) as d:
         tempdir = Path(d)
-        source = tempdir / "dropsuid.c"
-        source.write_text(DROPSUID_SOURCE)
-        binary = tempdir / "dropsuid"
+        source = tempdir / "{name}.c"
+        source.write_text(c_code)
+        binary = tempdir / name
         cmd = ["/usr/bin/gcc", "-g", str(source), "-o", str(binary)]
         subprocess.run(cmd, check=True)
         # Grant everyone read permission on the directory!
@@ -107,7 +112,7 @@ def create_dropsuid() -> Iterator[str]:
 @contextlib.contextmanager
 def create_suid(tmpdir: str = "/var/tmp") -> Iterator[str]:
     """Creates a `sleep` suid binary in a subdirectory of `tmpdir`."""
-    src_bin = os.path.realpath("/bin/sleep")
+    src_bin = get_gnu_coreutils_cmd("sleep")
     with tempfile.TemporaryDirectory(dir=tmpdir) as tempdir:
         binary = f"{tempdir}/sleep"
         shutil.copy(src_bin, binary)
@@ -118,8 +123,6 @@ def create_suid(tmpdir: str = "/var/tmp") -> Iterator[str]:
 
 
 MAIL_UID = 8
-test_package = "coreutils"
-test_source = "coreutils"
 
 # (core ulimit (bytes), expect core file)
 core_ulimit_table = [(1000, False), (10000000, True), (-1, True)]
@@ -140,7 +143,7 @@ required_fields = [
 class T(unittest.TestCase):
     # pylint: disable=missing-class-docstring,missing-function-docstring
     # pylint: disable=protected-access,too-many-public-methods
-    TEST_EXECUTABLE = os.path.realpath("/bin/sleep")
+    TEST_EXECUTABLE = get_gnu_coreutils_cmd("sleep")
     TEST_ARGS = ["86400"]
     maxDiff = None
     orig_core_dir: str
@@ -251,7 +254,7 @@ class T(unittest.TestCase):
         st2 = os.stat(test_report)
         self.assertNotEqual(st, st2, "original seen report gets overwritten")
 
-        pr = apport.Report()
+        pr = apport.report.Report()
         with open(test_report, "rb") as f:
             pr.load(f)
         self.assertTrue(
@@ -442,7 +445,7 @@ class T(unittest.TestCase):
         leak = os.path.join(
             apport.fileutils.report_dir, f"_usr_bin_perl.{os.getuid()}.crash"
         )
-        pr = apport.Report()
+        pr = apport.report.Report()
         with open(leak, "rb") as f:
             pr.load(f)
         # On a leak, no report is created since the executable path will be
@@ -483,7 +486,13 @@ class T(unittest.TestCase):
 
         resource.setrlimit(resource.RLIMIT_CORE, (-1, -1))
 
-        self.do_crash(command=myexe, expect_corefile=False, uid=8, suid_dumpable=2)
+        self.do_crash(
+            command=myexe,
+            expect_corefile=True,
+            expect_corefile_owner=0,
+            uid=8,
+            suid_dumpable=2,
+        )
 
     def test_core_dump_packaged(self) -> None:
         """Packaged executables create core dumps on proper ulimits."""
@@ -550,7 +559,7 @@ class T(unittest.TestCase):
 
         resource.setrlimit(resource.RLIMIT_CORE, (-1, -1))
 
-        def inject_bogus_report():
+        def inject_bogus_report() -> None:
             read, write = os.pipe()
             pid = os.fork()
             if pid > 0:
@@ -566,6 +575,7 @@ class T(unittest.TestCase):
             # replace report with the crafted one above as soon as it exists
             # and becomes deletable for us; this is a busy loop, we need to be
             # really fast to intercept
+            assert self.test_report
             while True:
                 try:
                     os.unlink(self.test_report)
@@ -582,7 +592,7 @@ class T(unittest.TestCase):
         """Ignore executables."""
         test_report = self.do_crash()
 
-        pr = apport.Report()
+        pr = apport.report.Report()
         with open(test_report, "rb") as f:
             pr.load(f)
         os.unlink(test_report)
@@ -603,46 +613,30 @@ class T(unittest.TestCase):
         os.chmod(myexe, 0o755)
         time.sleep(1)
 
+        test_proc = self.create_test_process(command=myexe)
         try:
-            test_proc = self.create_test_process(command=myexe)
-
             # bump mtime of myexe to make it more recent than process start
             # time; ensure this works with file systems with only second
             # resolution
             time.sleep(1.1)
             os.utime(myexe, None)
 
-            app = subprocess.run(
-                [
-                    str(APPORT_PATH),
-                    "-p",
-                    str(test_proc.pid),
-                    "-s",
-                    "42",
-                    "-c",
-                    "0",
-                    "-d",
-                    "1",
-                ],
-                check=False,
-                input=b"foo",
-                stderr=subprocess.PIPE,
-            )
-            err = app.stderr.decode()
-            self.assertEqual(app.returncode, 0, err)
-            if os.getuid() > 0:
-                self.assertIn("executable was modified after program start", err)
-            else:
-                with open("/var/log/apport.log", encoding="utf-8") as f:
-                    lines = f.readlines()
-                self.assertIn("executable was modified after program start", lines[-1])
+            with self.assertLogs(level="ERROR") as info_logs:
+                with open(myexe, "rb") as fake_coredump_fd:
+                    self._call_apport_directly(
+                        psutil.Process(test_proc.pid), 42, 1, fake_coredump_fd
+                    )
+
         finally:
             test_proc.kill()
             test_proc.wait()
 
+        self.assertIn(
+            "executable was modified after program start", info_logs.output[0]
+        )
         self._check_report(expect_report=False)
 
-    def test_logging_file(self):
+    def test_logging_file(self) -> None:
         """Output to log file, if available."""
         test_proc = self.create_test_process()
         log = os.path.join(self.workdir, "apport.log")
@@ -688,7 +682,8 @@ class T(unittest.TestCase):
         self.assertNotIn("Traceback", logged)
 
         self._check_report()
-        pr = apport.Report()
+        pr = apport.report.Report()
+        assert self.test_report
         with open(self.test_report, "rb") as f:
             pr.load(f)
 
@@ -696,7 +691,7 @@ class T(unittest.TestCase):
         self.assertEqual(pr["ExecutablePath"], self.TEST_EXECUTABLE)
         self.assertEqual(pr["CoreDump"], b"hel\x01lo")
 
-    def test_logging_stderr(self):
+    def test_logging_stderr(self) -> None:
         """Output to stderr if log is not available."""
         test_proc = self.create_test_process()
         try:
@@ -733,7 +728,8 @@ class T(unittest.TestCase):
         self.assertNotIn("Traceback", app.stderr)
 
         self._check_report()
-        pr = apport.Report()
+        pr = apport.report.Report()
+        assert self.test_report
         with open(self.test_report, "rb") as f:
             pr.load(f)
 
@@ -746,28 +742,48 @@ class T(unittest.TestCase):
         """Report generation for setuid program which stays root."""
         with create_suid() as suid:
             resource.setrlimit(resource.RLIMIT_CORE, (-1, -1))
-            # if a user can crash a suid root binary, it should not create
-            # core files
+            # If a user can crash a suid root binary, the core file should
+            # only be readable by root.
             # run test program in /run (which should only be writable to root)
-            self.do_crash(command=suid, uid=MAIL_UID, suid_dumpable=2, cwd="/run")
+            self.do_crash(
+                command=suid,
+                expect_corefile=True,
+                expect_corefile_owner=0,
+                uid=MAIL_UID,
+                suid_dumpable=2,
+                cwd="/run",
+            )
 
     @unittest.skipIf(os.geteuid() != 0, "this test needs to be run as root")
     def test_crash_suid_dumpable_debug(self) -> None:
         """Report generation for setuid program with suid_dumpable set to 1."""
-        # if a user can crash a suid root binary, it should not create
-        # core files if /proc/sys/fs/suid_dumpable is set to 1 ("debug")
+        # if a user can crash a suid root binary, it should create
+        # core files anyway if /proc/sys/fs/suid_dumpable is set to 1 ("debug")
         with create_suid() as suid:
             resource.setrlimit(resource.RLIMIT_CORE, (-1, -1))
-            self.do_crash(command=suid, uid=MAIL_UID, suid_dumpable=1)
+            self.do_crash(
+                command=suid,
+                expect_corefile=True,
+                expect_corefile_owner=MAIL_UID,
+                expected_owner=MAIL_UID,
+                uid=MAIL_UID,
+                suid_dumpable=1,
+            )
 
     @unittest.skipIf(os.geteuid() != 0, "this test needs to be run as root")
     def test_crash_setuid_drop(self) -> None:
         """Report generation for setuid program which drops root."""
-        with create_dropsuid() as dropsuid:
+        with compile_c_code("dropsuid", DROPSUID_SOURCE) as dropsuid:
             resource.setrlimit(resource.RLIMIT_CORE, (-1, -1))
-            # if a user can crash a suid root binary, it should not create
-            # core files
-            self.do_crash(command=dropsuid, uid=MAIL_UID, suid_dumpable=2)
+            # If a user can crash a suid root binary, the core file should
+            # only be readable by root.
+            self.do_crash(
+                command=dropsuid,
+                expect_corefile=True,
+                expect_corefile_owner=0,
+                uid=MAIL_UID,
+                suid_dumpable=2,
+            )
 
     @unittest.skipIf(os.geteuid() != 0, "this test needs to be run as root")
     def test_crash_setuid_unpackaged(self) -> None:
@@ -776,11 +792,12 @@ class T(unittest.TestCase):
         # regards as not packaged
         with create_suid(tmpdir="/tmp") as suid:
             resource.setrlimit(resource.RLIMIT_CORE, (-1, -1))
-            # if a user can crash a suid root binary, it should not create
-            # core files
+            # If a user can crash a suid root binary, the core file should
+            # only be readable by root.
             self.do_crash(
                 command=suid,
-                expect_corefile=False,
+                expect_corefile=True,
+                expect_corefile_owner=0,
                 expect_report=False,
                 uid=MAIL_UID,
                 suid_dumpable=2,
@@ -794,7 +811,7 @@ class T(unittest.TestCase):
         """
         test_report = self.do_crash(via_socket=True)
 
-        pr = apport.Report()
+        pr = apport.report.Report()
         with open(test_report, "rb") as f:
             pr.load(f)
         self.assertEqual(pr["Signal"], "11")
@@ -813,14 +830,19 @@ class T(unittest.TestCase):
     @unittest.skipIf(os.geteuid() != 0, "this test needs to be run as root")
     def test_crash_setuid_drop_via_socket(self) -> None:
         """Report generation via socket for setuid program which drops root."""
-        with create_dropsuid() as dropsuid:
+        with compile_c_code("dropsuid", DROPSUID_SOURCE) as dropsuid:
             resource.setrlimit(resource.RLIMIT_CORE, (-1, -1))
             test_report = self.do_crash(
-                command=dropsuid, uid=MAIL_UID, suid_dumpable=2, via_socket=True
+                command=dropsuid,
+                expect_corefile=True,
+                expect_corefile_owner=0,
+                uid=MAIL_UID,
+                suid_dumpable=2,
+                via_socket=True,
             )
 
             # check crash report
-            report = apport.Report()
+            report = apport.report.Report()
             with open(test_report, "rb") as report_file:
                 report.load(report_file)
             self.assertEqual(report["Signal"], "11")
@@ -834,20 +856,21 @@ class T(unittest.TestCase):
         with (
             subprocess.Popen(command) as test_process,
             unittest.mock.patch("builtins.open", open_mock),
+            apport_binary.ProcPid(test_process.pid) as proc_pid,
         ):
             try:
-                same_ns = apport_binary.is_same_ns(test_process.pid, "mnt")
+                same_ns = apport_binary.is_same_ns(proc_pid, "mnt")
                 self.assertFalse(same_ns)
             finally:
                 test_process.kill()
         readlink_mock.assert_has_calls(
             [
-                unittest.mock.call(f"/proc/{test_process.pid}/ns/mnt"),
+                unittest.mock.call("ns/mnt", dir_fd=proc_pid.fd),
                 unittest.mock.call("/proc/self/ns/mnt"),
             ]
         )
         open_mock.assert_called_with(
-            f"/proc/{test_process.pid}/cgroup", encoding="utf-8"
+            "cgroup", encoding="utf-8", opener=proc_pid._opener
         )
 
     @unittest.skipIf(
@@ -870,6 +893,7 @@ class T(unittest.TestCase):
             expected_report.add_user_info()
             expected_report.add_os_info()
             expected_report.add_package_info()
+            expected_report["CoredumpPackageJson"] = '{\n  "elfType": "coredump"\n}'
             expected_report["Signal"] = "11"
             expected_report["SignalName"] = "SIGSEGV"
             expected_report["_HooksRun"] = "no"
@@ -916,7 +940,7 @@ class T(unittest.TestCase):
         self.assertEqual(exit_code, 0)
         reader_mock.assert_called_once_with()
         self._check_report()
-        report = apport.Report()
+        report = apport.report.Report()
         with open(self.test_report, "rb") as report_file:
             report.load(report_file, binary="compressed")
         self.assertEqual(report["CoreDump"].compressed_value, b"mocked core")
@@ -928,7 +952,9 @@ class T(unittest.TestCase):
     #
 
     @staticmethod
-    def _apport_args(process: psutil.Process, sig: int, dump_mode: int) -> list[str]:
+    def _apport_args(
+        process: psutil.Process, sig: int, dump_mode: int, pidfd: int
+    ) -> list[str]:
         return [
             f"-p{process.pid}",
             f"-s{sig}",
@@ -937,15 +963,35 @@ class T(unittest.TestCase):
             f"-P{process.pid}",
             f"-u{process.uids().real}",
             f"-g{process.gids().real}",
+            f"-F{pidfd}",
             "--",
             process.exe().replace("/", "!"),
         ]
 
-    def _call_apport(
+    def _call_apport_directly(
         self, process: psutil.Process, sig: int, dump_mode: int, stdin: typing.IO
     ) -> None:
-        cmd = [str(APPORT_PATH)] + self._apport_args(process, sig, dump_mode)
-        subprocess.check_call(cmd, stdin=stdin)
+
+        with (
+            unittest.mock.patch("sys.stdin", io.TextIOWrapper(stdin)),
+            unittest.mock.patch.object(
+                apport_binary, "get_apport_starttime", return_value=int(time.time())
+            ),
+            unittest.mock.patch.object(apport_binary, "init_error_log"),
+            unittest.mock.patch.object(apport_binary, "setup_signals"),
+            pidfd_open(process.pid) as pidfd,
+        ):
+            exit_code = apport_binary.main(
+                self._apport_args(process, sig, dump_mode, pidfd)
+            )
+        self.assertEqual(exit_code, 0)
+
+    def _call_apport_via_subprocess(
+        self, process: psutil.Process, sig: int, dump_mode: int, stdin: typing.IO
+    ) -> None:
+        with pidfd_open(process.pid) as pidfd:
+            cmd = [str(APPORT_PATH)] + self._apport_args(process, sig, dump_mode, pidfd)
+            subprocess.check_call(cmd, stdin=stdin, pass_fds=(pidfd,))
 
     @staticmethod
     def _forward_crash_to_container(
@@ -962,7 +1008,10 @@ class T(unittest.TestCase):
 
         with unittest.mock.patch("os.open") as os_open_mock:
             os_open_mock.side_effect = _mocked_os_open
-            apport_binary.forward_crash_to_container(args, coredump_fd, False)
+            with apport_binary.ProcPid(args.global_pid) as proc_pid:
+                apport_binary.forward_crash_to_container(
+                    args, proc_pid, coredump_fd, False
+                )
 
     def _call_apport_via_socket(
         self, process: psutil.Process, sig: int, dump_mode: int, stdin: typing.IO
@@ -975,30 +1024,35 @@ class T(unittest.TestCase):
         server.bind(socket_path)
         server.listen(1)
 
-        args = apport_binary.parse_arguments(self._apport_args(process, sig, dump_mode))
-        with unittest.mock.patch("apport.fileutils.search_map") as search_map_mock:
-            search_map_mock.return_value = True
-            self._forward_crash_to_container(socket_path, args, stdin.fileno())
-            search_map_mock.assert_called()
-
-        # call apport like systemd does via socket activation
-        def child_setup() -> None:
-            os.environ["LISTEN_FDNAMES"] = "connection"
-            os.environ["LISTEN_FDS"] = "1"
-            os.environ["LISTEN_PID"] = str(os.getpid())
-            # socket from server becomes fd 3 (SD_LISTEN_FDS_START)
-            conn = server.accept()[0]
-            os.dup2(conn.fileno(), 3)
-            conn.close()
-
         try:
-            subprocess.run(
-                [str(APPORT_PATH)],
-                check=True,
-                preexec_fn=child_setup,
-                pass_fds=[3],
-                stdin=subprocess.DEVNULL,
-            )
+            with pidfd_open(process.pid) as pidfd:
+                args = apport_binary.parse_arguments(
+                    self._apport_args(process, sig, dump_mode, pidfd)
+                )
+                with unittest.mock.patch(
+                    "apport.fileutils.search_map"
+                ) as search_map_mock:
+                    search_map_mock.return_value = True
+                    self._forward_crash_to_container(socket_path, args, stdin.fileno())
+                    search_map_mock.assert_called()
+
+                # call apport like systemd does via socket activation
+                def child_setup() -> None:
+                    os.environ["LISTEN_FDNAMES"] = "connection"
+                    os.environ["LISTEN_FDS"] = "1"
+                    os.environ["LISTEN_PID"] = str(os.getpid())
+                    # socket from server becomes fd 3 (SD_LISTEN_FDS_START)
+                    conn = server.accept()[0]
+                    os.dup2(conn.fileno(), 3)
+                    conn.close()
+
+                subprocess.run(
+                    [str(APPORT_PATH)],
+                    check=True,
+                    preexec_fn=child_setup,
+                    pass_fds=[3],
+                    stdin=subprocess.DEVNULL,
+                )
         finally:
             server.close()
 
@@ -1023,7 +1077,9 @@ class T(unittest.TestCase):
         )
         self.assertNotEqual(gdb.stdout.strip(), "")
 
-    def _check_report(self, expect_report=True, expected_owner=None):
+    def _check_report(
+        self, expect_report: bool = True, expected_owner: int | None = None
+    ) -> None:
         if not expect_report:
             self.assertEqual(apport.fileutils.get_all_reports(), [])
             return
@@ -1031,6 +1087,7 @@ class T(unittest.TestCase):
         if expected_owner is None:
             expected_owner = os.geteuid()
 
+        assert self.test_report
         self.assertEqual(apport.fileutils.get_all_reports(), [self.test_report])
         st = os.stat(self.test_report)
         self.assertEqual(
@@ -1115,14 +1172,16 @@ class T(unittest.TestCase):
         expect_corefile_owner: int | None = None,
         args: list[str] | None = None,
         suid_dumpable: int = 1,
-        hook_before_apport: Callable | None = None,
+        hook_before_apport: Callable[[], None] | None = None,
         expect_report: bool = True,
         via_socket: bool = False,
         cwd: str | None = None,
+        expected_owner: int | None = None,
         **kwargs: typing.Any,
     ) -> str:
         # TODO: Split into smaller functions/methods
-        # pylint: disable=too-many-branches,too-many-locals,too-many-statements
+        # pylint: disable=too-complex,too-many-branches,too-many-locals
+        # pylint: disable=too-many-statements
         """Generate a test crash.
 
         This runs command (by default TEST_EXECUTABLE) in cwd, lets it crash,
@@ -1183,7 +1242,7 @@ class T(unittest.TestCase):
             raise
 
         try:
-            command_process = self.wait_for_gdb_sleeping_child_process(
+            command_process = self.wait_for_gdb_child_process(
                 gdb.pid, expected_command or command
             )
 
@@ -1195,8 +1254,10 @@ class T(unittest.TestCase):
 
             if via_socket:
                 call_apport = self._call_apport_via_socket
+            elif uid is None:
+                call_apport = self._call_apport_directly
             else:
-                call_apport = self._call_apport
+                call_apport = self._call_apport_via_subprocess
             with open(gdb_core_file, "rb") as core_fd:
                 call_apport(command_process, sig, suid_dumpable, core_fd)
             os.unlink(gdb_core_file)
@@ -1237,7 +1298,7 @@ class T(unittest.TestCase):
 
         self._check_report(
             expect_report=expect_report,
-            expected_owner=0 if suid_dumpable == 2 else os.geteuid(),
+            expected_owner=0 if suid_dumpable == 2 else expected_owner,
         )
         return self.test_report
 
@@ -1284,15 +1345,15 @@ class T(unittest.TestCase):
             f"{os.path.realpath(command).replace('/', '_')}.{uid}.crash",
         )
 
-    def check_report_coredump(self, report_path):
+    def check_report_coredump(self, report_path: str) -> None:
         """Check that given report file has a valid core dump."""
-        r = apport.Report()
+        r = apport.report.Report()
         with open(report_path, "rb") as f:
             r.load(f)
         self.assertIn("CoreDump", r)
         self.assertGreater(len(r["CoreDump"]), 5000)
         r.add_gdb_info()
-        self.assertIn("\n#2", r.get("Stacktrace"))
+        self.assertIn("\n#2", r["Stacktrace"])
 
     def wait_for_core_file(self, gdb_pid: int, core_file: str) -> None:
         """Wait for GDB to finish generating the core file.
@@ -1360,17 +1421,17 @@ class T(unittest.TestCase):
     # False positive return statement for unittest.TestCase.fail
     # See https://github.com/pylint-dev/pylint/issues/4167
     # pylint: disable-next=inconsistent-return-statements
-    def wait_for_gdb_sleeping_child_process(
-        self, gdb_pid: int, command: str
+    def wait_for_gdb_child_process(
+        self, gdb_pid: int, command: str, expected_status: str = "sleeping"
     ) -> psutil.Process:
         """Wait until GDB execv()ed the child process."""
         gdb_process = psutil.Process(gdb_pid)
         timeout = 0.0
         while timeout < 5:
-            gdb_children = gdb_process.children()
+            gdb_children = gdb_process.children(recursive=True)
             for process in gdb_children:
                 try:
-                    if process.status() != "sleeping":
+                    if process.status() != expected_status:
                         continue
                     cmdline = process.cmdline()
                 except psutil.NoSuchProcess:  # pragma: no cover
@@ -1382,13 +1443,13 @@ class T(unittest.TestCase):
             timeout += 0.1
 
         self.fail(
-            f"GDB child process {command} not started within "
-            f"{int(timeout)} seconds. GDB children: {gdb_children!r}"
+            f"GDB child process {command} with status {expected_status!r} not started"
+            f" within {int(timeout)} seconds. GDB children: {gdb_children!r}"
         )
 
     @unittest.mock.patch("time.sleep")
-    def test_wait_for_gdb_sleeping_child_process(self, sleep_mock: MagicMock) -> None:
-        """Test wait_for_gdb_sleeping_child_process() helper method."""
+    def test_wait_for_gdb_child_process(self, sleep_mock: MagicMock) -> None:
+        """Test wait_for_gdb_child_process() helper method."""
         child = MagicMock(spec=psutil.Process)
         child.status.side_effect = [
             "tracing-stop",  # child not yet started
@@ -1404,7 +1465,7 @@ class T(unittest.TestCase):
                 [child],  # child ready
             ]
 
-            self.wait_for_gdb_sleeping_child_process(123456789, self.TEST_EXECUTABLE)
+            self.wait_for_gdb_child_process(123456789, self.TEST_EXECUTABLE)
 
         sleep_mock.assert_called_with(0.1)
         self.assertEqual(sleep_mock.call_count, 3)
@@ -1413,13 +1474,13 @@ class T(unittest.TestCase):
 
     @unittest.mock.patch("psutil.Process", spec=psutil.Process)
     @unittest.mock.patch("time.sleep")
-    def test_wait_for_gdb_sleeping_child_process_timeout(
+    def test_wait_for_gdb_child_process_timeout(
         self, sleep_mock: MagicMock, process_mock: MagicMock
     ) -> None:
-        """Test wait_for_gdb_sleeping_child_process() helper runs into timeout."""
+        """Test wait_for_gdb_child_process() helper runs into timeout."""
         process_mock.return_value.children.return_value = []
         with unittest.mock.patch.object(self, "fail") as fail_mock:
-            self.wait_for_gdb_sleeping_child_process(123456789, self.TEST_EXECUTABLE)
+            self.wait_for_gdb_child_process(123456789, self.TEST_EXECUTABLE)
         fail_mock.assert_called_once()
         sleep_mock.assert_called_with(0.1)
         self.assertEqual(sleep_mock.call_count, 51)
