@@ -1,8 +1,6 @@
 """System tests for the apport.packaging_impl.apt_dpkg module."""
 
 # pylint: disable=missing-function-docstring,too-many-lines
-# TODO: Address following pylint complaints
-# pylint: disable=invalid-name
 
 import glob
 import gzip
@@ -15,8 +13,8 @@ import textwrap
 import typing
 from collections.abc import Iterator
 
+import apt_pkg
 import pytest
-from apt import apt_pkg
 
 from apport.packaging_impl.apt_dpkg import _parse_deb822_sources, impl
 from tests.helper import has_internet
@@ -315,12 +313,12 @@ def test_install_packages_system(
         rootdir,
         None,
         release,
-        [("coreutils", impl.get_version("coreutils")), ("tzdata", "1.1")],
+        [("gzip", impl.get_version("gzip")), ("tzdata", "1.1")],
         False,
         cachedir,
     )
 
-    assert os.path.exists(os.path.join(rootdir, "usr/bin/stat"))
+    assert os.path.exists(os.path.join(rootdir, "/usr/bin/gzip"))
     assert os.path.exists(os.path.join(rootdir, "usr/share/zoneinfo/zone.tab"))
 
     # complains about obsolete packages
@@ -333,22 +331,20 @@ def test_install_packages_system(
         os.path.join(cachedir, "system", "apt", "var", "cache", "apt", "archives")
     )
     cache_names = [p.split("_")[0] for p in cache]
-    assert "coreutils" in cache_names
-    assert "coreutils-dbgsym" in cache_names
+    assert "gzip" in cache_names
+    assert "gzip-dbgsym" in cache_names
     assert "tzdata" in cache_names
 
     # works with relative paths and existing cache
-    os.unlink(os.path.join(rootdir, "usr/bin/stat"))
+    os.unlink(os.path.join(rootdir, "usr/bin/gzip"))
     os.unlink(os.path.join(rootdir, "packages.txt"))
     orig_cwd = os.getcwd()
     try:
         os.chdir(workdir)
-        impl.install_packages(
-            "root", None, release, [("coreutils", None)], False, "cache"
-        )
+        impl.install_packages("root", None, release, [("gzip", None)], False, "cache")
     finally:
         os.chdir(orig_cwd)
-        assert os.path.exists(os.path.join(rootdir, "usr/bin/stat"))
+        assert os.path.exists(os.path.join(rootdir, "usr/bin/gzip"))
 
 
 @pytest.mark.skipif(not has_internet(), reason="online test")
@@ -694,6 +690,7 @@ def test_get_source_tree_sandbox(
         rootdir, os.path.join(configdir, release), "ubuntu", "jammy", origins=None
     )
     res = impl.get_source_tree("base-files", out_dir, sandbox=rootdir)
+    assert res is not None
     assert os.path.isdir(os.path.join(res, "debian"))
     # this needs to be updated when the release in _setup_foonux_config
     # changes
@@ -716,6 +713,7 @@ def test_get_source_tree_lp_sandbox(
     res = impl.get_source_tree(
         wanted_package, out_dir, version=wanted_version, sandbox=rootdir
     )
+    assert res is not None
     assert os.path.isdir(os.path.join(res, "debian"))
     # this needs to be updated when the release in _setup_foonux_config
     # changes
@@ -742,7 +740,7 @@ def test_create_sources_for_a_named_ppa(
         if {"deb", "deb-src"} == set(e.types)
         and "jammy" in e.suites
         and "main" in e.comps
-        and "http://ppa.launchpad.net/" "daisy-pluckers/daisy-seeds/ubuntu" in e.uris
+        and "http://ppa.launchpad.net/daisy-pluckers/daisy-seeds/ubuntu" in e.uris
     ]
     assert [
         e
@@ -750,7 +748,7 @@ def test_create_sources_for_a_named_ppa(
         if "deb" in e.types
         and "jammy" in e.suites
         and "main/debug" in e.comps
-        and "http://ppa.launchpad.net/" "daisy-pluckers/daisy-seeds/ubuntu" in e.uris
+        and "http://ppa.launchpad.net/daisy-pluckers/daisy-seeds/ubuntu" in e.uris
     ]
 
     trusted_gpg_d = pathlib.Path(rootdir) / "etc" / "apt" / "trusted.gpg.d"
@@ -1011,7 +1009,7 @@ def _setup_foonux_config(
     keyring_dir = os.path.join(config_release_dir, "trusted.gpg.d")
     _copy_ubuntu_keyrings(keyring_dir)
     # Create an architecture specific symlink, otherwise it cannot be
-    # found for armhf in __AptDpkgPackageInfo._build_apt_sandbox() as
+    # found for armhf in _AptDpkgPackageInfo._build_apt_sandbox() as
     # that looks for trusted.gpg.d relative to sources.list.
     keyring_arch_dir = os.path.join(armhf_dir, "trusted.gpg.d")
     os.symlink("../trusted.gpg.d", keyring_arch_dir)
