@@ -10,8 +10,6 @@
 # the full text of the license.
 
 # pylint: disable=too-many-lines
-# TODO: Address following pylint complaints
-# pylint: disable=invalid-name
 
 import io
 import os
@@ -32,7 +30,7 @@ from tests.paths import get_data_directory, local_test_environment
 try:
     import gi
 
-    gi.require_version("Gtk", "3.0")  # noqa: E402, pylint: disable=C0413
+    gi.require_version("Gtk", "3.0")
     from gi.repository import GLib, GObject, Gtk
 
     GLib.log_set_always_fatal(
@@ -48,7 +46,9 @@ if not GI_IMPORT_ERROR:
     apport_gtk = import_module_from_file(apport_gtk_path)
     GTKUserInterface = apport_gtk.GTKUserInterface
 else:
+    # pylint: disable-next=invalid-name
     apport_gtk = None
+    # pylint: disable-next=invalid-name
     GTKUserInterface = None
 
 
@@ -1210,7 +1210,7 @@ class T(unittest.TestCase):  # pylint: disable=too-many-public-methods
         self.app.ui_update_view()
 
     @staticmethod
-    def has_click_event_connected(widget):
+    def has_click_event_connected(widget: "Gtk.Widget") -> None:
         signal_id = GObject.signal_lookup("clicked", widget)
         signal_handler_id = GObject.signal_handler_find(
             widget,
