@@ -1,15 +1,12 @@
 """Unit tests for the apport.crashdb module."""
 
-# TODO: Address following pylint complaints
-# pylint: disable=invalid-name
-
 import copy
 import os.path
 import shutil
 import tempfile
 import textwrap
 import unittest
-from unittest.mock import MagicMock
+from unittest.mock import MagicMock, patch
 
 import apport.report
 from apport.crashdb_impl.memory import CrashDatabase
@@ -537,20 +534,20 @@ class T(unittest.TestCase):  # pylint: disable=too-many-public-methods
         b["Package"] = "bash 5"
 
         with (
-            unittest.mock.patch.object(
+            patch.object(
                 a, "crash_signature", MagicMock(return_value="/bin/bash:11:read:main")
             ),
-            unittest.mock.patch.object(
+            patch.object(
                 a,
                 "crash_signature_addresses",
                 MagicMock(return_value="/bin/bash:11:/lib/libc.so+123:/bin/bash+DEAD"),
             ),
-            unittest.mock.patch.object(
+            patch.object(
                 s,
                 "crash_signature",
                 MagicMock(return_value="/bin/bash:11:__getch:read:main"),
             ),
-            unittest.mock.patch.object(
+            patch.object(
                 s,
                 "crash_signature_addresses",
                 MagicMock(
@@ -558,12 +555,12 @@ class T(unittest.TestCase):  # pylint: disable=too-many-public-methods
                     ":/bin/bash+DEAD"
                 ),
             ),
-            unittest.mock.patch.object(
+            patch.object(
                 b,
                 "crash_signature",
                 MagicMock(return_value="/bin/bash:11:__getch:read:main"),
             ),
-            unittest.mock.patch.object(
+            patch.object(
                 b,
                 "crash_signature_addresses",
                 MagicMock(return_value="/bin/bash:11:/lib/libc.so+123:/bin/bash+DEAD"),
@@ -605,17 +602,15 @@ class T(unittest.TestCase):  # pylint: disable=too-many-public-methods
 
             # addr DB should have both possible patterns on a
             # pylint: disable=protected-access
+            b_sig_addr = b.crash_signature_addresses()
+            assert b_sig_addr is not None
             self.assertEqual(
-                self.crashes._duplicate_search_address_signature(
-                    b.crash_signature_addresses()
-                ),
-                5,
+                self.crashes._duplicate_search_address_signature(b_sig_addr), 5
             )
+            s_sig_addr = s.crash_signature_addresses()
+            assert s_sig_addr is not None
             self.assertEqual(
-                self.crashes._duplicate_search_address_signature(
-                    s.crash_signature_addresses()
-                ),
-                5,
+                self.crashes._duplicate_search_address_signature(s_sig_addr), 5
             )
 
     def test_check_duplicate_reopen(self) -> None:
@@ -764,20 +759,26 @@ class T(unittest.TestCase):  # pylint: disable=too-many-public-methods
 
         # give #0 a long symbolic sig which needs lots of quoting
         symb = self.crashes.download(0)
-        symb.crash_signature = lambda: "s+" * 1000
 
         # and #1 a long addr sig
         addr = self.crashes.download(1)
-        addr.crash_signature_addresses = lambda: "0x1+/" * 1000
 
-        self.assertIsNone(self.crashes.known(symb))
-        self.assertIsNone(self.crashes.check_duplicate(0))
-        self.assertIsNone(self.crashes.known(addr))
-        self.assertIsNone(self.crashes.check_duplicate(1))
+        with (
+            patch.object(symb, "crash_signature", MagicMock(return_value="s+" * 1000)),
+            patch.object(
+                addr,
+                "crash_signature_addresses",
+                MagicMock(return_value="0x1+/" * 1000),
+            ),
+        ):
+            self.assertIsNone(self.crashes.known(symb))
+            self.assertIsNone(self.crashes.check_duplicate(0))
+            self.assertIsNone(self.crashes.known(addr))
+            self.assertIsNone(self.crashes.check_duplicate(1))
 
-        self.crashes.duplicate_db_publish(self.dupdb_dir)
-        self.assertEqual(self.crashes.known(symb), "http://foo.bugs.example.com/0")
-        self.assertEqual(self.crashes.known(addr), "http://foo.bugs.example.com/1")
+            self.crashes.duplicate_db_publish(self.dupdb_dir)
+            self.assertEqual(self.crashes.known(symb), "http://foo.bugs.example.com/0")
+            self.assertEqual(self.crashes.known(addr), "http://foo.bugs.example.com/1")
 
     def test_change_master_id(self) -> None:
         """duplicate_db_change_master_id()"""
