@@ -7,18 +7,23 @@
 # option) any later version.  See http://www.gnu.org/copyleft/gpl.html for
 # the full text of the license.
 
-"""Unit tests for apport.unicode_gettext."""
+"""Unit tests for deprecated functions in apport."""
 
 import unittest
-import unittest.mock
 
-from apport import unicode_gettext
+from apport import fatal, unicode_gettext
 
 
 class TestDeprecation(unittest.TestCase):
-    """Unit tests for apport.unicode_gettext."""
+    """Unit tests for deprecated functions in apport."""
 
     def test_unicode_gettext(self) -> None:
         """unicode_gettext() throws a deprecation warning."""
         with self.assertWarns(PendingDeprecationWarning):
             self.assertEqual(unicode_gettext("untranslated"), "untranslated")
+
+    def test_deprecated_logging_function(self) -> None:
+        """apport.fatal() throws a deprecation warning."""
+        with self.assertRaisesRegex(SystemExit, "^1$"):
+            with self.assertWarns(DeprecationWarning):
+                fatal("fatal error")
