@@ -15,6 +15,7 @@ import unittest.mock
 from unittest.mock import MagicMock
 
 import apt
+import apt.package
 
 from apport.packaging_impl.apt_dpkg import (
     _map_mirror_to_arch,
@@ -25,7 +26,7 @@ from apport.packaging_impl.apt_dpkg import (
 
 
 @unittest.mock.patch(
-    "apport.packaging_impl.apt_dpkg.__AptDpkgPackageInfo.get_os_version",
+    "apport.packaging_impl.apt_dpkg._AptDpkgPackageInfo.get_os_version",
     MagicMock(return_value=("Ubuntu", "22.04")),
 )
 class TestPackagingAptDpkg(unittest.TestCase):
@@ -33,6 +34,16 @@ class TestPackagingAptDpkg(unittest.TestCase):
 
     maxDiff = None
 
+    def setUp(self) -> None:
+        # Clear APT cache to allow mocking it
+        # pylint: disable-next=protected-access
+        impl._apt_cache = None
+
+    def tearDown(self) -> None:
+        # Clear APT cache to clear cached mocks
+        # pylint: disable-next=protected-access
+        impl._apt_cache = None
+
     @unittest.mock.patch("apt.Cache", spec=apt.Cache)
     def test_is_distro_package_no_candidate(self, apt_cache_mock: MagicMock) -> None:
         """is_distro_package() for package that has no candidate."""
@@ -326,3 +337,31 @@ var/lib/ieee-data/iab.txt				    net/ieee-data
             },
         )
         open_mock.assert_called_once_with("Contents-amd64", "rb")
+
+
+class TestPackaging(unittest.TestCase):
+    """Unit tests for apport.packaging.PackageInfo class."""
+
+    def setUp(self) -> None:
+        # pylint: disable-next=protected-access
+        impl._os_version = None
+
+    def tearDown(self) -> None:
+        # pylint: disable-next=protected-access
+        impl._os_version = None
+
+    @unittest.mock.patch("platform.freedesktop_os_release")
+    def test_get_os_version_debian_testing(self, os_release_mock: MagicMock) -> None:
+        """Test get_os_version() for Debian testing (no VERSION_ID set)."""
+        # platform.freedesktop_os_release() data from base-files 13.7
+        os_release_mock.return_value = {
+            "NAME": "Debian GNU/Linux",
+            "ID": "debian",
+            "PRETTY_NAME": "Debian GNU/Linux trixie/sid",
+            "VERSION_CODENAME": "trixie",
+            "HOME_URL": "https://www.debian.org/",
+            "SUPPORT_URL": "https://www.debian.org/support",
+            "BUG_REPORT_URL": "https://bugs.debian.org/",
+        }
+        self.assertEqual(impl.get_os_version(), ("Debian", "n/a"))
+        os_release_mock.assert_called_once_with()
