@@ -1,8 +1,5 @@
 """Unit tests for the problem_report module."""
 
-# TODO: Address following pylint complaints
-# pylint: disable=invalid-name
-
 import base64
 import contextlib
 import datetime
@@ -14,7 +11,7 @@ import textwrap
 import time
 import unittest
 import unittest.mock
-from unittest.mock import MagicMock
+from unittest.mock import MagicMock, patch
 
 try:
     import zstandard
@@ -23,7 +20,7 @@ except ImportError:
 
 import problem_report
 
-bin_data = b"ABABABABAB\0\0\0Z\x01\x02"
+BIN_DATA = b"ABABABABAB\0\0\0Z\x01\x02"
 
 
 class T(unittest.TestCase):  # pylint: disable=too-many-public-methods
@@ -380,7 +377,7 @@ class T(unittest.TestCase):  # pylint: disable=too-many-public-methods
 
     def test_write_fileobj(self) -> None:
         """Write a report with a pointer to a file-like object."""
-        tempbin = io.BytesIO(bin_data)
+        tempbin = io.BytesIO(BIN_DATA)
         tempasc = io.BytesIO(b"Hello World")
 
         pr = problem_report.ProblemReport(date="now!")
@@ -411,6 +408,30 @@ class T(unittest.TestCase):  # pylint: disable=too-many-public-methods
         out = io.BytesIO()
         self.assertRaises(OSError, pr.write, out)
 
+    @patch("problem_report.CompressedValue.iter_compressed.__defaults__", (48,))
+    def test_write_compressed_value(self) -> None:
+        """Write a report with a multi-line compressed value."""
+        report = problem_report.ProblemReport(date="now!")
+        report["BinValue"] = problem_report.CompressedValue(
+            compressed_value=b"\x1f\x8b\x08\x00\x00\x00\x00\x00\x02\xff\x0b\xc9HUH\xcc"
+            b"+.O-R(\xc9W\xc8\xc9LK\xd5Q(\x01\x8a\x95\xe6e\x96\xa5\x16\x15\x03y\x89y)"
+            b"\n\xa9@veIFf^:\x00\xa6\xbfr\x950\x00\x00\x00"
+        )
+        out = io.BytesIO()
+        report.write(out)
+        self.assertEqual(
+            out.getvalue().decode(),
+            textwrap.dedent(
+                """\
+                ProblemType: Crash
+                Date: now!
+                BinValue: base64
+                 H4sIAAAAAAAC/wvJSFVIzCsuTy1SKMlXyMlMS9VRKAGKleZllqUWFQN5iXkpCqlA
+                 dmVJRmZeOgCmv3KVMAAAAA==
+                """
+            ),
+        )
+
     def test_read_file(self) -> None:
         """Read a report with binary data."""
         bin_report = textwrap.dedent(
@@ -427,7 +448,7 @@ class T(unittest.TestCase):  # pylint: disable=too-many-public-methods
         # test with reading everything
         pr = problem_report.ProblemReport()
         pr.load(io.BytesIO(bin_report))
-        self.assertEqual(pr["File"], bin_data)
+        self.assertEqual(pr["File"], BIN_DATA)
         self.assertEqual(pr.has_removed_fields(), False)
 
         # test with skipping binary data
@@ -440,8 +461,8 @@ class T(unittest.TestCase):  # pylint: disable=too-many-public-methods
         self.assertEqual(pr["Foo"], "Bar")
         self.assertEqual(pr.has_removed_fields(), False)
         self.assertTrue(isinstance(pr["File"], problem_report.CompressedValue))
-        self.assertEqual(len(pr["File"]), len(bin_data))
-        self.assertEqual(pr["File"].get_value(), bin_data)
+        self.assertEqual(len(pr["File"]), len(BIN_DATA))
+        self.assertEqual(pr["File"].get_value(), BIN_DATA)
         self.assertEqual(pr["File"].name, "File")
 
     def test_read_file_legacy(self) -> None:
@@ -511,23 +532,40 @@ class T(unittest.TestCase):  # pylint: disable=too-many-public-methods
         ).encode()
 
         pr = problem_report.ProblemReport()
-        pr.load(io.BytesIO(report))
+        pr.load(io.BytesIO(report), binary="compressed")
 
         self.assertEqual(pr["Long"], "xxx\n.\nyyy")
         self.assertEqual(pr["Short"], "Bar")
-        self.assertEqual(pr["File"], b"ABABABABABABABABABAB\0\0\0\0\0\0\0\0\0\0Z")
+        self.assertEqual(
+            pr["File"].get_value(), b"ABABABABABABABABABAB\0\0\0\0\0\0\0\0\0\0Z"
+        )
 
         # write back unmodified
         out = io.BytesIO()
         pr.write(out)
-        self.assertEqual(out.getvalue(), report)
+        self.assertEqual(
+            out.getvalue().decode(),
+            textwrap.dedent(
+                """\
+                ProblemType: Crash
+                Date: now!
+                Long:
+                 xxx
+                 .
+                 yyy
+                Short: Bar
+                File: base64
+                 H4sICAAAAAAC/0ZpbGUAc3RyxIAMcBAFAK/2p9MfAAAA
+                """
+            ),
+        )
 
         pr["Short"] = "aaa\nbbb"
         pr["Long"] = "123"
         out = io.BytesIO()
         pr.write(out)
         self.assertEqual(
-            out.getvalue(),
+            out.getvalue().decode(),
             textwrap.dedent(
                 """\
                 ProblemType: Crash
@@ -537,10 +575,9 @@ class T(unittest.TestCase):  # pylint: disable=too-many-public-methods
                  aaa
                  bbb
                 File: base64
-                 H4sICAAAAAAC/0ZpbGUA
-                 c3RyxIAMcBAFAK/2p9MfAAAA
+                 H4sICAAAAAAC/0ZpbGUAc3RyxIAMcBAFAK/2p9MfAAAA
                 """
-            ).encode(),
+            ),
         )
 
     def test_sorted_items(self) -> None:
@@ -775,7 +812,7 @@ class T(unittest.TestCase):  # pylint: disable=too-many-public-methods
         """Import a dictionary with update()."""
         pr = problem_report.ProblemReport()
         pr["oldtext"] = "Hello world"
-        pr["oldbin"] = bin_data
+        pr["oldbin"] = BIN_DATA
         pr["overwrite"] = "I am crap"
 
         d = {
@@ -786,7 +823,7 @@ class T(unittest.TestCase):  # pylint: disable=too-many-public-methods
 
         pr.update(d)
         self.assertEqual(pr["oldtext"], "Hello world")
-        self.assertEqual(pr["oldbin"], bin_data)
+        self.assertEqual(pr["oldbin"], BIN_DATA)
         self.assertEqual(pr["newtext"], "Goodbye world")
         self.assertEqual(pr["newbin"], "11\000\001\002\xffZZ")
         self.assertEqual(pr["overwrite"], "I am good")
@@ -809,7 +846,7 @@ class T(unittest.TestCase):  # pylint: disable=too-many-public-methods
         pr = problem_report.ProblemReport()
         pr.load(io.BytesIO(report), key_filter=["DataYes", "GoodFile"])
         self.assertEqual(pr["DataYes"], "yesyes")
-        self.assertEqual(pr["GoodFile"], bin_data)
+        self.assertEqual(pr["GoodFile"], BIN_DATA)
         self.assertEqual(sorted(pr.keys()), ["DataYes", "GoodFile"])
 
     def test_get_on_disk_size(self) -> None:
