@@ -1,8 +1,6 @@
 """Unit tests for the apport.report module."""
 
 # pylint: disable=too-many-lines
-# TODO: Address following pylint complaints
-# pylint: disable=invalid-name
 
 import datetime
 import io
@@ -124,8 +122,48 @@ Mems_allowed_list:	0
 voluntary_ctxt_switches:	3
 nonvoluntary_ctxt_switches:	0
 """
+DIVIDE_BY_ZERO_COREDUMP_PACKAGE_JSON = """\
+{
+  "elfType": "coredump",
+  "elfArchitecture": "AMD x86-64",
+  "/usr/bin/divide-by-zero": {
+    "type": "deb",
+    "os": "ubuntu",
+    "name": "chaos-marmosets",
+    "version": "0.2.0-1",
+    "architecture": "amd64",
+    "buildId": "24601d1b3f7720e1fd85f8ce46784527891e4a93"
+  },
+  "linux-vdso.so.1": {
+    "type": "deb",
+    "os": "ubuntu",
+    "name": "linux",
+    "version": "6.14.0-15.15",
+    "architecture": "amd64",
+    "buildId": "b6d4e1f58edbdcbaefeafda9ceb46b976dcb3c7a"
+  },
+  "ld-linux-x86-64.so.2": {
+    "type": "deb",
+    "os": "ubuntu",
+    "name": "glibc",
+    "version": "2.41-6ubuntu1",
+    "architecture": "amd64",
+    "buildId": "6a459ffce8a7a1a8ac06398efe8b5ad9cbbee781"
+  },
+  "libc.so.6": {
+    "type": "deb",
+    "os": "ubuntu",
+    "name": "glibc",
+    "version": "2.41-6ubuntu1",
+    "architecture": "amd64",
+    "buildId": "467f544f15035abef911999cbc14489edd0555ab"
+  }
+}
+"""
 DIVIDE_BY_ZERO_REPORT = f"""\
 ProblemType: Crash
+CoredumpPackageJson:
+{re.sub("^", " ", DIVIDE_BY_ZERO_COREDUMP_PACKAGE_JSON.rstrip(), flags=re.MULTILINE)}
 CurrentDesktop: Unity:Unity7:ubuntu
 Date: Mon Oct 30 13:40:03 2023
 ExecutablePath: /usr/bin/divide-by-zero
@@ -247,7 +285,19 @@ DIVIDE_BY_ZERO_SYSTEMD_COREDUMP = {
     "\n1:/dev/pts/2\npos:\t0\nflags:\t02002002\nmnt_id:\t27\nino:\t5\n"
     "\n2:/dev/pts/2\npos:\t0\nflags:\t02002002\nmnt_id:\t27\nino:\t5\n",
     "COREDUMP_OWNER_UID": "1000",
-    "COREDUMP_PACKAGE_JSON": '{"elfType":"coredump","elfArchitecture":"AMD x86-64"}',
+    "COREDUMP_PACKAGE_JSON": '{"elfType":"coredump","elfArchitecture":"AMD x86-64",'
+    '"/usr/bin/divide-by-zero":{"type":"deb","os":"ubuntu",'
+    '"name":"chaos-marmosets","version":"0.2.0-1",'
+    '"architecture":"amd64","buildId":"24601d1b3f7720e1fd85f8ce46784527891e4a93"},'
+    '"linux-vdso.so.1":{"type":"deb","os":"ubuntu",'
+    '"name":"linux","version":"6.14.0-15.15",'
+    '"architecture":"amd64","buildId":"b6d4e1f58edbdcbaefeafda9ceb46b976dcb3c7a"},'
+    '"ld-linux-x86-64.so.2":{"type":"deb","os":"ubuntu",'
+    '"name":"glibc","version":"2.41-6ubuntu1",'
+    '"architecture":"amd64","buildId":"6a459ffce8a7a1a8ac06398efe8b5ad9cbbee781"},'
+    '"libc.so.6":{"type":"deb","os":"ubuntu",'
+    '"name":"glibc","version":"2.41-6ubuntu1",'
+    '"architecture":"amd64","buildId":"467f544f15035abef911999cbc14489edd0555ab"}}',
     "COREDUMP_PID": 284582,
     "COREDUMP_PROC_AUXV": b"!" + b"\x00" * 8 + b"\x10\xde\xd4\xff\x7f\x00\x003",
     "COREDUMP_PROC_CGROUP": "0::/user.slice/user-1000.slice/user"
@@ -275,7 +325,7 @@ DIVIDE_BY_ZERO_EXECUTABLE_STAT = os.stat_result(
 
 class T(unittest.TestCase):
     # pylint: disable=missing-class-docstring,missing-function-docstring
-    # pylint: disable=protected-access
+    # pylint: disable=protected-access,too-many-public-methods
     maxDiff = None
 
     def test_has_useful_stacktrace(self) -> None:
@@ -1313,6 +1363,20 @@ No symbol table info available.
 """
         self.assertIsNone(pr.crash_signature_addresses())
 
+    def test_crash_signature_addresses_error_in_proc_maps(self) -> None:
+        """crash_signature_addresses() with error in ProcMaps"""
+        report = apport.report.Report()
+        report["ExecutablePath"] = "/usr/bin/sleep"
+        report["Signal"] = "42"
+        with tempfile.TemporaryDirectory() as proc_pid_dir:
+            pid_fd = os.open(proc_pid_dir, os.O_RDONLY | os.O_PATH | os.O_DIRECTORY)
+            report.add_proc_info(proc_pid_fd=pid_fd)
+            os.close(pid_fd)
+            self.assertIn("[Errno ", report["ProcMaps"])
+        report["Stacktrace"] = "mocked stack trace"
+
+        self.assertIsNone(report.crash_signature_addresses())
+
     @staticmethod
     @unittest.mock.patch("os.geteuid")
     def test_missing_uid(geteuid_mock: MagicMock) -> None:
@@ -1489,12 +1553,14 @@ No symbol table info available.
         report_output = io.BytesIO()
         report.write(report_output)
 
-        expected_report = (
-            DIVIDE_BY_ZERO_REPORT + "CoreDump: base64\n"
-            " H4sICAAAAAAC/0NvcmVEdW1wAA==\n"
-            " q3f1cWNiZGSAAgC2f6EYDwAAAA==\n"
+        report_without_coredump = re.sub(
+            "\nCoreDump:.*", "\n", report_output.getvalue().decode(), flags=re.DOTALL
         )
-        self.assertEqual(report_output.getvalue().decode(), expected_report)
+        self.assertEqual(report_without_coredump, DIVIDE_BY_ZERO_REPORT)
+        written_report = apport.report.Report()
+        report_output.seek(0)
+        written_report.load(report_output)
+        self.assertEqual(written_report["CoreDump"], coredump["COREDUMP"])
         stat_mock.assert_called_once_with("/usr/bin/divide-by-zero")
 
     @unittest.mock.patch("os.stat")
@@ -1511,6 +1577,24 @@ No symbol table info available.
         self.assertEqual(report_output.getvalue().decode(), DIVIDE_BY_ZERO_REPORT)
         stat_mock.assert_called_once_with("/usr/bin/divide-by-zero")
 
+    def test_report_from_systemd_coredump_missing_executable(self) -> None:
+        """Test converting systemd-coredump with the executable missing.
+
+        See also https://launchpad.net/bugs/2098792
+        """
+        coredump = DIVIDE_BY_ZERO_SYSTEMD_COREDUMP.copy()
+        coredump["COREDUMP_EXE"] = "/tmp/executable-already-gone"
+
+        report = apport.report.Report.from_systemd_coredump(coredump)
+
+        self.assertEqual(report["ExecutablePath"], "/tmp/executable-already-gone")
+        self.assertEqual(
+            report["ExecutableTimestamp"],
+            "Error: Executable '/tmp/executable-already-gone' not found",
+        )
+
+        self.assertIsNone(report.get_executable_timestamp())
+
     def test_add_kernel_crash_info_no_vmcore(self) -> None:
         """add_kernel_crash_info() on a non-kernel crash."""
         report = apport.report.Report()
@@ -1568,3 +1652,53 @@ No symbol table info available.
         tmpfile = called_cmd[-1]
         self.assertRegex(tmpfile, r"^/.*/apport_vmcore_\w{8}$")
         self.assertFalse(pathlib.Path(tmpfile).exists())
+
+    @unittest.mock.patch("subprocess.run")
+    def test_get_ld_search_paths(self, run_mock: MagicMock) -> None:
+        run_mock.return_value = subprocess.CompletedProcess(
+            args=MagicMock(),
+            returncode=0,
+            stdout=textwrap.dedent(
+                """\
+                path.prefix="/usr"
+                path.sysconfdir="/etc"
+                path.system_dirs[0x0]="/lib/x86_64-linux-gnu/"
+                path.system_dirs[0x1]="/usr/lib/x86_64-linux-gnu/"
+                path.system_dirs[0x2]="/lib/"
+                path.system_dirs[0x3]="/usr/lib/"
+                """
+            ),
+        )
+        ld_search_paths = apport.report._get_ld_search_paths()
+        self.assertEqual(
+            ld_search_paths,
+            [
+                "/lib/x86_64-linux-gnu/",
+                "/usr/lib/x86_64-linux-gnu/",
+                "/lib/",
+                "/usr/lib/",
+            ],
+        )
+        run_mock.assert_called_once_with(
+            ["ld.so", "--list-diagnostics"],
+            check=True,
+            stdout=subprocess.PIPE,
+            text=True,
+        )
+
+    @unittest.mock.patch("subprocess.run")
+    def test_get_ld_search_paths_sorting(self, run_mock: MagicMock) -> None:
+        run_mock.return_value = subprocess.CompletedProcess(
+            args=MagicMock(),
+            returncode=0,
+            stdout=textwrap.dedent(
+                """\
+                path.system_dirs[0x2]="third"
+                path.system_dirs[0x1]="second"
+                path.system_dirs[0x0]="first"
+                """
+            ),
+        )
+        ld_search_paths = apport.report._get_ld_search_paths("ld.so")
+        self.assertEqual(ld_search_paths, ["first", "second", "third"])
+        run_mock.assert_called_once()
