@@ -9,6 +9,7 @@
 
 """Unit tests for data/apport."""
 
+import argparse
 import datetime
 import errno
 import io
@@ -16,15 +17,17 @@ import os
 import pathlib
 import shutil
 import signal
+import subprocess
 import sys
 import tempfile
 import time
 import unittest
+import unittest.mock
 from unittest.mock import MagicMock
 
 import apport.fileutils
 import apport.user_group
-from tests.helper import import_module_from_file
+from tests.helper import import_module_from_file, pidfd_open
 from tests.paths import get_data_directory
 
 apport_binary = import_module_from_file(get_data_directory() / "apport")
@@ -87,7 +90,7 @@ class TestApport(unittest.TestCase):
     def test_refine_core_ulimit_huge(self) -> None:
         """Test refine_core_ulimit() with huge limit."""
         options = apport_binary.parse_arguments(
-            ["-p", str(os.getpid()), "-c", str(pow(2, 64))]
+            ["-p", str(os.getpid()), "-d", "1", "-c", str(pow(2, 64))]
         )
         self.assertEqual(apport_binary.refine_core_ulimit(options), -1)
 
@@ -101,6 +104,42 @@ class TestApport(unittest.TestCase):
         self.assertEqual(sys.stderr, stderr)
         isatty_mock.assert_called_once_with(2)
 
+    def test_pidfd_getpid_process_gone(self) -> None:
+        """Test pidfd_getpid() for a pidfd where the process is gone."""
+        with subprocess.Popen(["sleep", "3600"]) as test_process:
+            try:
+                pidfd = os.pidfd_open(test_process.pid)
+            finally:
+                test_process.kill()
+        try:
+            pid = apport_binary.pidfd_getpid(pidfd)
+            self.assertEqual(pid, -1)
+        finally:
+            os.close(pidfd)
+
+    def test_pidfd_getpid_on_stdout(self) -> None:
+        """Test pidfd_getpid() on stdout which is an invalid pidfd."""
+        fd = sys.stdout.fileno()
+        with self.assertRaisesRegex(OSError, f"Bad file descriptor: {fd}"):
+            apport_binary.pidfd_getpid(fd)
+
+    def test_proc_pid_not_exist(self) -> None:
+        """Test ProcPid().exits() returning False."""
+        with apport_binary.ProcPid(os.getpid()) as proc_pid:
+            self.assertFalse(proc_pid.exists("nonexistent"))
+
+    def test_proc_pid_has_same_pid(self) -> None:
+        """Test ProcPid.has_same_pid() for same process."""
+        pid = os.getpid()
+        with apport_binary.ProcPid(pid) as proc_pid, pidfd_open(pid) as pidfd:
+            self.assertTrue(proc_pid.has_same_pid(pidfd))
+
+    def test_proc_pid_has_same_pid_false(self) -> None:
+        """Test ProcPid.has_same_pid() for different processes."""
+        pid = os.getpid()
+        with apport_binary.ProcPid(pid) as proc_pid, pidfd_open(1) as pidfd:
+            self.assertFalse(proc_pid.has_same_pid(pidfd))
+
     def test_receive_arguments_via_socket_import_error(self) -> None:
         """Test receive_arguments_via_socket() fail to import systemd."""
         with (
@@ -128,15 +167,37 @@ class TestApport(unittest.TestCase):
         with self.assertRaisesRegex(SystemExit, "^1$"):
             apport_binary.receive_arguments_via_socket()
 
-    @unittest.mock.patch.object(apport_binary, "init_error_log", MagicMock())
+    @unittest.mock.patch.object(apport_binary, "check_lock", MagicMock())
     @unittest.mock.patch.object(
         apport_binary, "is_same_ns", MagicMock(return_value=False)
     )
     @unittest.mock.patch.object(apport_binary, "forward_crash_to_container")
-    def test_main_forward_crash_to_container(self, forward_mock: MagicMock) -> None:
-        """Test main() to forward crash to container."""
-        args = ["-p", "12345", "-P", "67890"]
-        self.assertEqual(apport_binary.main(args), 0)
+    def test_forward_crash_to_container(self, forward_mock: MagicMock) -> None:
+        """process_crash_from_kernel_with_proc_pid() to forward crash to container."""
+        fake_pid = 67890
+        yesterday = int(time.clock_gettime(time.CLOCK_BOOTTIME) * 100) - 86400
+        options = apport_binary.parse_arguments(
+            ["-p", "12345", "-d", "1", "-P", str(fake_pid)]
+        )
+        with tempfile.TemporaryDirectory() as tmpdir:
+            stat = pathlib.Path(tmpdir) / "stat"
+            stat.write_text(f"{fake_pid} (name) ?{' x' * 18} {yesterday} ...\n")
+            status = pathlib.Path(tmpdir) / "status"
+            status.write_text("Name:\tname\nUid:\t0\t0\t0\t0\nGid:\t0\t0\t0\t0\n")
+            exe = pathlib.Path(tmpdir) / "exe"
+            os.symlink(sys.executable, exe)
+            root = pathlib.Path(tmpdir) / "root"
+            container_exe = root / pathlib.Path(sys.executable).relative_to("/")
+            container_exe.parent.mkdir(parents=True)
+            container_exe.touch(mode=0o755)
+            cmdline = pathlib.Path(tmpdir) / "cmdline"
+            cmdline.write_text("name\0")
+            with apport_binary.ProcPid(fake_pid, tmpdir) as proc_pid:
+                exit_code = apport_binary.process_crash_from_kernel_with_proc_pid(
+                    options, proc_pid
+                )
+
+        self.assertEqual(exit_code, 0)
         forward_mock.assert_called_once()
 
     @unittest.mock.patch.object(apport_binary, "init_error_log", MagicMock())
@@ -166,7 +227,7 @@ class TestApport(unittest.TestCase):
     def test_consistency_checks_replaced_process(self) -> None:
         """Test consistency_checks() for a replaced crash process ID."""
         pid = os.getpid()
-        options = apport_binary.parse_arguments(["-p", str(pid)])
+        options = apport_binary.parse_arguments(["-p", str(pid), "-d", "1"])
         now = int(time.clock_gettime(time.CLOCK_BOOTTIME) * 100)
         crash_user = apport.user_group.get_process_user_and_group()
         with apport_binary.ProcPid(pid) as proc_pid:
@@ -174,6 +235,66 @@ class TestApport(unittest.TestCase):
                 apport_binary.consistency_checks(options, now, proc_pid, crash_user)
             )
 
+    def test_process_crash_from_kernel_replaced_process(self) -> None:
+        """Test process_crash_from_kernel() to abort if process ID has been reused.
+
+        Instead of actual replacing the process with a new one with the same ID,
+        just use a different pidfd.
+        """
+        pidfd = os.pidfd_open(os.getpid())
+        with (
+            self.assertLogs(level="ERROR") as info_logs,
+            subprocess.Popen(["sleep", "3600"]) as test_process,
+        ):
+            try:
+                args = [
+                    "-p",
+                    str(test_process.pid),
+                    "-d",
+                    "1",
+                    "-P",
+                    str(test_process.pid),
+                    "-F",
+                    str(pidfd),
+                ]
+                options = apport_binary.parse_arguments(args)
+                exit_code = apport_binary.process_crash_from_kernel(options)
+            finally:
+                test_process.kill()
+
+        self.assertEqual(exit_code, 1)
+        self.assertIn(
+            f"The process {test_process.pid} has already been replaced by a new"
+            f" process with the same ID. Ignoring crash.",
+            info_logs.output[0],
+        )
+
+    @unittest.mock.patch.object(apport_binary, "check_lock", MagicMock())
+    def test_consistency_checks_before_forwarding(self) -> None:
+        """Test that consistency checks are done before forwarding to container."""
+        fake_pid = 67890
+        future = int(time.clock_gettime(time.CLOCK_BOOTTIME) * 100) + 3600
+        options = apport_binary.parse_arguments(
+            ["-p", "12345", "-d", "1", "-P", str(fake_pid)]
+        )
+        with (
+            self.assertLogs(level="ERROR") as info_logs,
+            tempfile.TemporaryDirectory() as tmpdir,
+        ):
+            stat = pathlib.Path(tmpdir) / "stat"
+            stat.write_text(f"{fake_pid} (name) ?{' x' * 18} {future} ...\n")
+            status = pathlib.Path(tmpdir) / "status"
+            status.write_text("Name:\tname\nUid:\t42\t42\t42\t42\nGid:\t7\t7\t7\t7\n")
+            with apport_binary.ProcPid(fake_pid, tmpdir) as proc_pid:
+                exit_code = apport_binary.process_crash_from_kernel_with_proc_pid(
+                    options, proc_pid
+                )
+
+        self.assertEqual(exit_code, 0)
+        self.assertIn(
+            "process was replaced after Apport started, ignoring", info_logs.output[0]
+        )
+
     def test_consistency_checks_mismatching_uid(self) -> None:
         """Test consistency_checks() for a mitmatching UID."""
         pid = os.getpid()
@@ -182,6 +303,8 @@ class TestApport(unittest.TestCase):
             [
                 "-p",
                 str(pid),
+                "-d",
+                "1",
                 "-u",
                 str(crash_user.uid + 1),
                 "-g",
@@ -291,7 +414,8 @@ class TestApport(unittest.TestCase):
             with tempfile.NamedTemporaryFile() as stdin:
                 stdin_mock = io.FileIO(stdin.name)
                 with unittest.mock.patch("sys.stdin", return_value=stdin_mock):
-                    self.assertEqual(apport_binary.main(["-p", str(fake_pid)]), 1)
+                    exit_code = apport_binary.main(["-p", str(fake_pid), "-d", "1"])
+                    self.assertEqual(exit_code, 1)
         self.assertIn("/proc/2147483647 not found", error_logs.output[0])
 
     @unittest.mock.patch.object(apport_binary, "check_lock", MagicMock())
@@ -310,7 +434,16 @@ class TestApport(unittest.TestCase):
         which should be tested in a separate unit test.
         """
         is_systemd_watchdog_restart_mock.return_value = True
-        args = ["-p", str(os.getpid()), "-s", str(int(signal.SIGABRT)), "-c", "-1"]
+        args = [
+            "-p",
+            str(os.getpid()),
+            "-d",
+            "1",
+            "-s",
+            str(int(signal.SIGABRT)),
+            "-c",
+            "-1",
+        ]
         with self.assertLogs(level="ERROR") as error_logs:
             with tempfile.NamedTemporaryFile() as stdin:
                 stdin_mock = io.TextIOWrapper(io.FileIO(stdin.name))
@@ -341,6 +474,70 @@ class TestApport(unittest.TestCase):
             error_logs.output[0],
         )
 
+    def test_parse_arguments(self) -> None:
+        """Test parse_arguments()"""
+        args = [
+            "-p42477",
+            "-s4",
+            "-c0",
+            "-d1",
+            "-P42477",
+            "-u1000",
+            "-g1000",
+            "-F3",
+            "--",
+            "!usr!bin!divide-by-zero",
+        ]
+        options = apport_binary.parse_arguments(args)
+
+        expected_options = argparse.Namespace(
+            pid=42477,
+            signal_number=4,
+            core_ulimit=0,
+            dump_mode=1,
+            global_pid=42477,
+            pidfd=3,
+            uid=1000,
+            gid=1000,
+            executable_path="/usr/bin/divide-by-zero",
+            systemd_coredump_instance=None,
+            start=False,
+            stop=False,
+        )
+        self.assertEqual(options, expected_options)
+
+    def test_parse_arguments_kernel_without_pidfd(self) -> None:
+        """Test parse_arguments() from kernel without pidfd (%F) support."""
+        args = [
+            "-p42477",
+            "-s4",
+            "-c0",
+            "-d1",
+            "-P42477",
+            "-u1000",
+            "-g1000",
+            "-F",
+            "--",
+            "!usr!bin!divide-by-zero",
+        ]
+        options = apport_binary.parse_arguments(args)
+
+        expected_options = argparse.Namespace(
+            pid=42477,
+            signal_number=4,
+            core_ulimit=0,
+            dump_mode=1,
+            global_pid=42477,
+            pidfd=None,
+            uid=1000,
+            gid=1000,
+            executable_path="/usr/bin/divide-by-zero",
+            systemd_coredump_instance=None,
+            start=False,
+            stop=False,
+        )
+        self.assertEqual(options, expected_options)
+
     def test_systemd_journal_import_error(self) -> None:
         """Test handling missing systemd.journal library correctly."""
         with (
